<?php

require_once __DIR__."/constants.php";
require_once __DIR__."/listing.php";
if (file_exists(__DIR__."/admin_pro.php"))
  include_once __DIR__."/admin_pro.php";
require_once __DIR__."/apicall_subinfo.php";

////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Add options needed for plugin

add_option('fubaby_ebayCampaignID', ''); //The ebay campaign id.
add_option('fubaby_ebayDefCustomID', ''); //The ebay custom id.
add_option('fubaby_ebayGlobalID', fu_ebay_getDefGlobalIdForLocale()); // Ebay Global ID.
add_option('fubaby_ebayDefCategory', ''); // Default category IDs. 
add_option('fubaby_ebayDefSeller', ''); // Default seller. 
add_option('fubaby_ebayDefSellerType', ''); // Default seller type. 
add_option('fubaby_ebayDefColumns', 2); // Default columns of search results.
add_option('fubaby_ebayDefRows', 1); // Default rows of search results.
add_option('fubaby_ebayDefSort', fuEbaySortOrder::BestMatch); // Default sort order of search results
add_option('fubaby_ebayPicWidthItem', 225); // Default width of pictures for single items.
add_option('fubaby_ebayPicWidthList', 225); // Default width of pictures for search listings.
add_option('fubaby_ebayPicWidthWidget', 225); // Default width of pictures for widgets.
add_option('fubaby_ebayColourStyle', fuEbayColourStyle::Default); // Default colour style
add_option('fubaby_ebayTitleMaxLines', 3); // Max title lines to display.
add_option('fubaby_ebayDefArrangementItem', fuEbayArrangement::ImageLeft); // Default arrangement for single items.
add_option('fubaby_ebayDefArrangementList', fuEbayArrangement::TitleBelow); // Default arrangement for search listings.
add_option('fubaby_ebayDefArrangementWidget', fuEbayArrangement::TitleBelow); // Default arrangement for widgets.
add_option('fubaby_ebayDefSlideshowStyle', fuEbaySlideShowStyle::Manual); // Default slideshow style
add_option('fubaby_ebayDefDisplayFieldsItem', fuEbayDisplayFields::ItemDefault); // Default fields to show for single items
add_option('fubaby_ebayDefDisplayFieldslist', fuEbayDisplayFields::ListingDefault); // Default fields to show for search listings
add_option('fubaby_ebayDefDisplayFieldsWidget', fuEbayDisplayFields::ListingDefault); // Default fields to show for widgets
add_option('fubaby_ebayDefNumSlides', 3); // Default number of slideshow slides
add_option('fubaby_ebayEmptySearchMsg', __('No items found', "fast-ebay-listings")); // Default empty results message.
add_option('fubaby_ebayPriorityListingText', __('Great Deal!', "fast-ebay-listings")); // Default default priority listing text
add_option('fubaby_ebayNewWindow', 1); // Whether to open ebay links in new window/tab.
add_option('fubaby_ebayDeferredLoading', fuEbayDeferedLoading::NotCached); // Whether to open ebay links in new window/tab.
add_option('fubaby_ebaySubscriptionKey', ""); // Key for subscription.
add_option('fubaby_ebayDisplayFELLink', 0); // Whether to display a link to Fast eBay Listings

////////////////////////////////////////////////////////////////////////////////////////////////////////
// Remove options on uninstall.

function fu_ebay_uninstall()
{
  delete_option('fubaby_ebayPublisherID');
  delete_option('fubaby_ebayCampaignID');
  delete_option('fubaby_ebayGlobalID');
  delete_option('fubaby_ebayDefCustomID');
  delete_option('fubaby_ebayDefCategory');
  delete_option('fubaby_ebayDefSeller');
  delete_option('fubaby_ebayDefSellerType');
  delete_option('fubaby_ebayDefColumns');
  delete_option('fubaby_ebayDefRows');
  delete_option('fubaby_ebayDefSort');
  delete_option('fubaby_ebayGeoTarget');
  delete_option('fubaby_ebayPicWidthItem');
  delete_option('fubaby_ebayPicWidthList');
  delete_option('fubaby_ebayPicWidthWidget');
  delete_option('fubaby_ebayColourStyle');
  delete_option('fubaby_ebayTitleMaxLines');
  delete_option('fubaby_ebayDefArrangementItem');
  delete_option('fubaby_ebayDefArrangementList');
  delete_option('fubaby_ebayDefArrangementWidget');
  delete_option('fubaby_ebayDefDisplayFieldsItem');
  delete_option('fubaby_ebayDefDisplayFieldsList');
  delete_option('fubaby_ebayDefDisplayFieldsWidget');
  delete_option('fubaby_ebayDefSlideshowStyle');
  delete_option('fubaby_ebayDefNumSlides');
  delete_option('fubaby_ebayEmptySearchMsg');
  delete_option('fubaby_ebayPriorityListingText');
  delete_option('fubaby_ebayNewWindow');
  delete_option('fubaby_ebayDeferredLoading');
  delete_option('fubaby_ebaySubscriptionKey');
  delete_option('fubaby_ebayDisplayFELLink');
  
  // Bring in Pro features
  if (function_exists("fu_ebaypro_uninstall"))
    fu_ebaypro_uninstall();
}

// Infer the default eBay Marketplace/GlobalId from the site locale region code.
function fu_ebay_getDefGlobalIdForLocale()
{
  $validGlobalIds = array(
    'EBAY-AT','EBAY-AU','EBAY-BE','EBAY-CA','EBAY-CH','EBAY-DE','EBAY-ES','EBY-FR','EBAY-GB','EBAY-HK','EBAY-IE','EBAY-IN','EBAY-IT','EBAY-MY','EBAY-NL','EBAY-PH','EBAY-PL','EBAY-SG','EBAY-TH','EBAY-TW','EBAY-VN','EBAY-US',
  );

  if (class_exists("Locale"))
  {
    $region = Locale::getRegion(get_locale());
    $globalId = "EBAY-$region";
    return in_array($globalId, $validGlobalIds) ? $globalId : "EBAY-US";
  }
  return "EBAY-US";
}

////////////////////////////////////////////////////////////////////////////////////////////////////////
// Admin page user interface

add_action('admin_menu', 'fu_ebay_menu');

function fu_ebay_menu() 
{
  
  add_options_page(
    FUBABY_EBAY_PLUGIN_TITLE . " " . __("Options", "fast-ebay-listings"), 
    FUBABY_EBAY_PLUGIN_TITLE, 
    'manage_options', 
    "fast-ebay-listings", //__FILE__, 
    function_exists('fu_ebaypro_options') ? 'fu_ebaypro_options' : 'fu_ebay_options');
	add_action( 'admin_init', 'fu_ebay_register_settings' );
}

///////////////////////////////////////////////////////////////////////////////////////
// Begin general options

function fu_ebay_register_settings()
{
  $apicall = new fuEbaySubInfoApiCall();
  $subInfo = $apicall->call(true);

  // First, we register a section. This is necessary since all future options must belong to one.
  add_settings_section(
      'fu_ebay_settings_section_general',         // ID used to identify this section and with which to register options
      __("General Options", "fast-ebay-listings"),                  // Title to be displayed on the administration page
      'fu_ebay_options_callback', // Callback used to render the description of the section
      'fu_ebay_options_general'   // Page on which to add this section of options
      );
   
  add_settings_field(
    'fubaby_ebayGlobalID',
    __('eBay Marketplace', "fast-ebay-listings"),
    'fu_ebay_globalid_callback',
    'fu_ebay_options_general',
    'fu_ebay_settings_section_general',
    array(
        'id' => 'fubaby_ebayGlobalID',
        'label' => __('eBay site to query items from', "fast-ebay-listings")
    )
    );
          
  add_settings_field(
      'fubaby_ebaySubscriptionKey',
      FUBABY_EBAY_PLUGIN_TITLE . " " . __("Premium Subscription Key", "fast-ebay-listings"),
      'fu_ebay_definput_callback',
      'fu_ebay_options_general',
      'fu_ebay_settings_section_general',
      array(
          'id' => 'fubaby_ebaySubscriptionKey',
          'label' => $subInfo,
          'width' => '50%'
      )
      );
  
  // Defaults Section
  add_settings_section(
      'fu_ebay_settings_section_defaults',
      __("Default Options", "fast-ebay-listings"),
      'fu_ebay_options_callback_default',
      'fu_ebay_options_defaults'
      );
  
  add_settings_field(
      'fubaby_ebayDefCategory',
      __('Default Category ID', "fast-ebay-listings"),
      'fu_ebay_category_callback',
      'fu_ebay_options_defaults',
      'fu_ebay_settings_section_defaults',
      array(
          'id' => 'fubaby_ebayDefCategory',
          'label' => __('Used for search results when no category is specified.', "fast-ebay-listings"),
          'pattern' => '[0-9]* .*',
          'width' => '50%'
      )
      );
  add_settings_field(
      'fubaby_ebayDefSeller',
      __('Default Seller ID(s)', "fast-ebay-listings"),
      'fu_ebay_definput_callback',
      'fu_ebay_options_defaults',
      'fu_ebay_settings_section_defaults',
      array(
          'id' => 'fubaby_ebayDefSeller',
          'label' => sprintf(
            /* translators: 1: special keyword 2: special keyword */ 
            __("Used for search results when no seller is specified (comma separated list). <br/>
Special key values:<br/><ul>
<li>'%1\$s' - (or left blank) to default to all sellers.</li>
<li>'%2\$s' - Use eBay username set on post author's profile.</li></ul>", 
              "fast-ebay-listings"), "all", "author")
      )
      );
  add_settings_field(
      'fubaby_ebayDefSellerType',
      __('Default Seller Type', "fast-ebay-listings"),
      'fu_ebay_sellertype_callback',
      'fu_ebay_options_defaults',
      'fu_ebay_settings_section_defaults',
      array(
          'id' => 'fubaby_ebayDefSellerType',
          'label' => __('Default seller account type to filter results by.', "fast-ebay-listings")
      )
      );      
  add_settings_field(
      'fubaby_ebayDefColumns',
      __('Default Results Columns', "fast-ebay-listings"),
      'fu_ebay_intinput_callback',
      'fu_ebay_options_defaults',
      'fu_ebay_settings_section_defaults',
      array(
          'id' => 'fubaby_ebayDefColumns',
          'label' => __('Default number of columns to split search results into.', "fast-ebay-listings")
      )
      );  
  add_settings_field(
      'fubaby_ebayDefRows',
      __('Default Results Rows', "fast-ebay-listings"),
      'fu_ebay_intinput_callback',
      'fu_ebay_options_defaults',
      'fu_ebay_settings_section_defaults',
      array(
          'id' => 'fubaby_ebayDefRows',
          'label' => __('Default number of rows to split search results into.', "fast-ebay-listings")
      )
      ); 
  add_settings_field(
      'fubaby_ebayDefSlideshowStyle',
      __('Default Slideshow Style', "fast-ebay-listings"),
      'fu_ebay_slideshowstyle_callback',
      'fu_ebay_options_defaults',
      'fu_ebay_settings_section_defaults',
      array(
          'id' => 'fubaby_ebayDefSlideshowStyle',
          'label' => __('Default slideshow style: when slideshow="default" on shortcodes.', "fast-ebay-listings")
      )
      );
  add_settings_field(
      'fubaby_ebayDefNumSlides',
      __('Default Number of Slides', "fast-ebay-listings"),
      'fu_ebay_intinput_callback',
      'fu_ebay_options_defaults',
      'fu_ebay_settings_section_defaults',
      array(
          'id' => 'fubaby_ebayDefNumSlides',
          'label' => __('Default number of slideshow slides.', "fast-ebay-listings")
      )
      );  
   add_settings_field(
      'fubaby_ebayDefSort',
      __('Default Results Sorting', "fast-ebay-listings"),
      'fu_ebay_sortorder_callback',
      'fu_ebay_options_defaults',
      'fu_ebay_settings_section_defaults',
      array(
          'id' => 'fubaby_ebayDefSort',
          'label' => __('Default sort order of search results.', "fast-ebay-listings")
      )
      );
      
  ////////////////////////////////////////////////////////////////
  // Cosmetic & Behaviour Section
  add_settings_section(
      'fu_ebay_settings_section_behaviour',
      __("Behavior Options", "fast-ebay-listings"),
      'fu_ebay_options_callback',
      'fu_ebay_options_behaviour'
      );
  
  add_settings_field(
    'fubaby_ebayEmptySearchMsg',
    __('Empty search results message', "fast-ebay-listings"),
    'fu_ebay_definput_callback',
    'fu_ebay_options_behaviour',
    'fu_ebay_settings_section_behaviour',
    array(
        'id' => 'fubaby_ebayEmptySearchMsg',
        'label' => __('Displayed when an eBay search returns no results.', "fast-ebay-listings"),
        'width' => '50%'
    )
    );
  add_settings_field(
      'fubaby_ebayPriorityListingText',
      __('Priority listing text', "fast-ebay-listings"),
      'fu_ebay_definput_callback',
      'fu_ebay_options_behaviour',
      'fu_ebay_settings_section_behaviour',
      array(
          'id' => 'fubaby_ebayPriorityListingText',
          'label' => __('Displayed to highlight priority listings, which earn more commission from EPN', "fast-ebay-listings"),
          'width' => '50%'
      )
      );
  add_settings_field(
      'fubaby_ebayNewWindow',
      __('Open in new window', "fast-ebay-listings"),
      'fu_ebay_checkbox_callback',
      'fu_ebay_options_behaviour',
      'fu_ebay_settings_section_behaviour',
      array(
          'id' => 'fubaby_ebayNewWindow',
          'label' => __('If ticked, eBay links will open in a new browser tab/window.', "fast-ebay-listings"),
      )
      ); 
  add_settings_field(
      'fubaby_ebayDeferredLoading',
      __('Deferred loading of listings', "fast-ebay-listings"),
      'fu_ebay_deferredloading_callback',
      'fu_ebay_options_behaviour',
      'fu_ebay_settings_section_behaviour',
      array(
          'id' => 'fubaby_ebayDeferredLoading',
          'label' => __("Defer loading of eBay listings to improve page load times.", "fast-ebay-listings") . "<br/>" .
                    __("Set to \"Always\" if you use a caching plugin to ensure up-to-date eBay listings are shown.", "fast-ebay-listings")
      )
      );
  add_settings_field(
      'fubaby_ebayDisplayFELLink',
      __("Display a link to plugin author's website", "fast-ebay-listings"),
      'fu_ebay_checkbox_callback',
      'fu_ebay_options_behaviour',
      'fu_ebay_settings_section_behaviour',
      array(
          'id' => 'fubaby_ebayDisplayFELLink',
          'label' => __("Tick to display a \"Powered by Fast eBay Listings\" link to plugin author's website.", "fast-ebay-listings"),
      )
      ); 

  // Cosmetic Section 
  add_settings_section(
    'fu_ebay_settings_section_cosmetic',
    __("Cosmetic Settings", "fast-ebay-listings"),
    'fu_ebay_options_callback',
    'fu_ebay_options_behaviour'
    );  

  add_settings_field(
    'fubaby_ebayColourStyle',
    __('Color Scheme', "fast-ebay-listings"),
    'fu_ebay_colourstyle_callback',
    'fu_ebay_options_behaviour',
    'fu_ebay_settings_section_cosmetic',
    array(
        'id' => 'fubaby_ebayColourStyle',
        'label' => __('Color scheme of all eBay results.', "fast-ebay-listings")
    )
    );

  add_settings_field(
    'fubaby_ebayTitleMaxLines',
    __('Max eBay Listing Title Lines', "fast-ebay-listings"),
    'fu_ebay_intinput_callback',
    'fu_ebay_options_behaviour',
    'fu_ebay_settings_section_cosmetic',
    array(
        'id' => 'fubaby_ebayTitleMaxLines',
        'label' => __('If set, limit eBay listing titles to maximum number of lines.', "fast-ebay-listings")
    )
    );      

  // Cosmetic & Behaviour - List Section 
  add_settings_section(
    'fu_ebay_settings_section_cosmetic_list',
    __("Search Listings Display Settings", "fast-ebay-listings"),
    'fu_ebay_options_callback_cosmetic_list',
    'fu_ebay_options_behaviour'
    );

  add_settings_field(
      'fubaby_ebayDefArrangementList',
      __('eBay Search Listings Arrangement', "fast-ebay-listings"),
      'fu_ebay_arrangement_callback',
      'fu_ebay_options_behaviour',
      'fu_ebay_settings_section_cosmetic_list',
      array(
          'id' => 'fubaby_ebayDefArrangementList'
      )
      );

  add_settings_field(
      'fubaby_ebayDefDisplayFieldsList',
      __('eBay Search Listing Fields to Display', "fast-ebay-listings"),
      'fu_ebay_displayfields_callback',
      'fu_ebay_options_behaviour',
      'fu_ebay_settings_section_cosmetic_list',
      array(
          'id' => 'fubaby_ebayDefDisplayFieldsList',
          'label' => __('Default eBay Fields to Display for search listings blocks & shortcodes', "fast-ebay-listings")
      )
      );

  add_settings_field(
      'fubaby_ebayPicWidthList',
      __('Default eBay Search Listings Picture Width', "fast-ebay-listings"),
      'fu_ebay_intinput_callback',
      'fu_ebay_options_behaviour',
      'fu_ebay_settings_section_cosmetic_list',
      array(
          'id' => 'fubaby_ebayPicWidthList',
          'label' => __('Default width of thumbnails for search listings blocks & shortcodes.', "fast-ebay-listings")
      )
      );  

  // Cosmetic & Behaviour - Widget Section 
  add_settings_section(
    'fu_ebay_settings_section_cosmetic_widget',
    __("Widget Listings Display Settings", "fast-ebay-listings"),
    'fu_ebay_options_callback_cosmetic_widget',
    'fu_ebay_options_behaviour'
    );

  add_settings_field(
    'fubaby_ebayDefArrangementWidget',
    __('eBay Widget Arrangement', "fast-ebay-listings"),
    'fu_ebay_arrangement_callback',
    'fu_ebay_options_behaviour',
    'fu_ebay_settings_section_cosmetic_widget',
    array(
        'id' => 'fubaby_ebayDefArrangementWidget'
    )
    );


  add_settings_field(
    'fubaby_ebayDefDisplayFieldsWidget',
    __('eBay Widget Fields to Display', "fast-ebay-listings"),
    'fu_ebay_displayfields_callback',
    'fu_ebay_options_behaviour',
    'fu_ebay_settings_section_cosmetic_widget',
    array(
        'id' => 'fubaby_ebayDefDisplayFieldsWidget',
        'label' => __('Default eBay Fields to Display for widgets', "fast-ebay-listings")
    )
    );
        
  add_settings_field(
    'fubaby_ebayPicWidthWidget',
    __('Default eBay Widget Picture Width', "fast-ebay-listings"),
    'fu_ebay_intinput_callback',
    'fu_ebay_options_behaviour',
    'fu_ebay_settings_section_cosmetic_widget',
    array(
        'id' => 'fubaby_ebayPicWidthWidget',
        'label' => __('Default width of thumbnails for widgets.', "fast-ebay-listings")
    )
    );  

  // Cosmetic & Behaviour - Item Section 
  add_settings_section(
    'fu_ebay_settings_section_cosmetic_item',
    __("Single Item Display Settings", "fast-ebay-listings"),
    'fu_ebay_options_callback_cosmetic_item',
    'fu_ebay_options_behaviour'
    );

  add_settings_field(
    'fubaby_ebayDefArrangementItem',
    __('eBay Single Item Arrangement', "fast-ebay-listings"),
    'fu_ebay_arrangement_callback',
    'fu_ebay_options_behaviour',
    'fu_ebay_settings_section_cosmetic_item',
    array(
        'id' => 'fubaby_ebayDefArrangementItem'
    )
    );  

  add_settings_field(
    'fubaby_ebayDefDisplayFieldsItem',
    __('eBay Single Item Fields to Display', "fast-ebay-listings"),
    'fu_ebay_displayfields_callback',
    'fu_ebay_options_behaviour',
    'fu_ebay_settings_section_cosmetic_item',
    array(
        'id' => 'fubaby_ebayDefDisplayFieldsItem',
        'label' => __('Default eBay Fields to Display for single item blocks & shortcodes', "fast-ebay-listings")
    )
    );
        
  add_settings_field(
      'fubaby_ebayPicWidthItem',
      __('Default eBay Item Picture Width', "fast-ebay-listings"),
      'fu_ebay_intinput_callback',
      'fu_ebay_options_behaviour',
      'fu_ebay_settings_section_cosmetic_item',
      array(
          'id' => 'fubaby_ebayPicWidthItem',
          'label' => __('Default width of thumbnails for single item blocks & shortcodes.', "fast-ebay-listings")
      )
      );   

  ////////////////////////////////////////////////////////////////
  // EPN Section
  add_settings_section(
      'fu_ebay_settings_section_epn',
      __("eBay Partner Network Options", "fast-ebay-listings"),
      'fu_ebay_options_callback_epn',
      'fu_ebay_options_epn'
      );
  
  add_settings_field(
      'fubaby_ebayCampaignID',
      __('Affiliate Campaign ID', "fast-ebay-listings"),
      'fu_ebay_definput_callback',
      'fu_ebay_options_epn',
      'fu_ebay_settings_section_epn',
      array(
          'id' => 'fubaby_ebayCampaignID',
          'label' => __('10 digit EPN campaign ID.', "fast-ebay-listings"),
          'pattern' => '[0-9]{10}'
      )
    );

  add_settings_field(
      'fubaby_ebayDefCustomID',
      __('Default Affiliate Custom ID', "fast-ebay-listings"),
      'fu_ebay_definput_callback',
      'fu_ebay_options_epn',
      'fu_ebay_settings_section_epn',
      array(
          'id' => 'fubaby_ebayDefCustomID',
          'label' => __('Default custom tracking ID to aid reporting in EPN.', "fast-ebay-listings")
      )
    );         


  // register our settings
  register_setting('fu_ebay_settings_general', 'fubaby_ebaySubscriptionKey');
  register_setting('fu_ebay_settings_general', 'fubaby_ebayGlobalID');

  register_setting('fu_ebay_settings_defaults', 'fubaby_ebayDefCategory');
  register_setting('fu_ebay_settings_defaults', 'fubaby_ebayDefSeller');
  register_setting('fu_ebay_settings_defaults', 'fubaby_ebayDefSellerType');
  register_setting('fu_ebay_settings_defaults', 'fubaby_ebayDefColumns');
  register_setting('fu_ebay_settings_defaults', 'fubaby_ebayDefRows');
  register_setting('fu_ebay_settings_defaults', 'fubaby_ebayDefSlideshowStyle');
  register_setting('fu_ebay_settings_defaults', 'fubaby_ebayDefNumSlides');
  register_setting('fu_ebay_settings_defaults', 'fubaby_ebayDefSort');

  register_setting('fu_ebay_settings_behaviour', 'fubaby_ebayPicWidthItem');
  register_setting('fu_ebay_settings_behaviour', 'fubaby_ebayPicWidthList');
  register_setting('fu_ebay_settings_behaviour', 'fubaby_ebayPicWidthWidget');
  register_setting('fu_ebay_settings_behaviour', 'fubaby_ebayDefArrangementItem');
  register_setting('fu_ebay_settings_behaviour', 'fubaby_ebayDefArrangementList');
  register_setting('fu_ebay_settings_behaviour', 'fubaby_ebayDefArrangementWidget');
  register_setting('fu_ebay_settings_behaviour', 'fubaby_ebayDefDisplayFieldsItem');
  register_setting('fu_ebay_settings_behaviour', 'fubaby_ebayDefDisplayFieldsList');
  register_setting('fu_ebay_settings_behaviour', 'fubaby_ebayDefDisplayFieldsWidget');
  register_setting('fu_ebay_settings_behaviour', 'fubaby_ebayEmptySearchMsg');
  register_setting('fu_ebay_settings_behaviour', 'fubaby_ebayPriorityListingText');
  register_setting('fu_ebay_settings_behaviour', 'fubaby_ebayNewWindow');
  register_setting('fu_ebay_settings_behaviour', 'fubaby_ebayDeferredLoading');
  register_setting('fu_ebay_settings_behaviour', 'fubaby_ebayDisplayFELLink');
  register_setting('fu_ebay_settings_behaviour', 'fubaby_ebayColourStyle');
  register_setting('fu_ebay_settings_behaviour', 'fubaby_ebayTitleMaxLines');

  register_setting('fu_ebay_settings_epn', 'fubaby_ebayCampaignID');
  register_setting('fu_ebay_settings_epn', 'fubaby_ebayDefCustomID');

  // Bring in Pro features
  if (function_exists("fu_ebaypro_register_settings"))
    fu_ebaypro_register_settings();
}

function fu_ebay_options(string $titleSuffix = "")
{
  if (!current_user_can('manage_options'))  {
    wp_die( __("You do not have sufficient permissions to access this page.", "fast-ebay-listings") );
  }  

  $logoCompatAppUrl = plugins_url(basename(__DIR__) . "/images/compatibleapplication.gif");  
  $bannerUrl = plugins_url(basename(__DIR__) . "/images/banner-772x250.jpg");  
  if (!empty($titleSuffix)) $titleSuffix = " - {$titleSuffix}";

  //Get the active tab from the $_GET param
  $default_tab = "general";
  $tab = isset($_GET['tab']) ? $_GET['tab'] : $default_tab;
  
  ?>
<div class="wrap">
  <h1>Fubaby <?php echo FUBABY_EBAY_PLUGIN_TITLE . $titleSuffix; ?></h1>
  <div style="float:right">
  <img src="<?php echo $logoCompatAppUrl; ?>" width="108" height="64" border="0" style="padding: 10px; background: #fff;" />
  </div>
  <img src="<?php echo $bannerUrl; ?>" width="772" height="250" border="0">

  <div class="fu_ebay_admin_row">
  <div class="fu_ebay_admin_col1">

      <nav class="nav-tab-wrapper">
        <?php 
        fu_ebay_admin_tab_html($tab, "general", __("General", "fast-ebay-listings"));
        fu_ebay_admin_tab_html($tab, "defaults", __("Default eBay Query Options", "fast-ebay-listings"));
        fu_ebay_admin_tab_html($tab, "behaviour", __("Cosmetic & Behavior", "fast-ebay-listings"));
        fu_ebay_admin_tab_html($tab, "epn", __("eBay Partner Network", "fast-ebay-listings"));

        if (function_exists("fu_ebaypro_admin_nav_tabs")) 
          fu_ebaypro_admin_nav_tabs($tab);
        ?>
      </nav>

      <!-- Create the form that will be used to render our options -->  
      <form method="post" action="options.php" id="fu_ebay_admin_form">  
        <?php settings_fields( "fu_ebay_settings_{$tab}" ); ?>  
        <div class="tab-content">
        <?php do_settings_sections( "fu_ebay_options_{$tab}" ); ?>
        </div>           
        <?php submit_button(); ?>  
      </form>  
    </div>
    <div class="fu_ebay_admin_col2">
      <div class="fu_ebay_admin_box">
        <h2><?php _e("Need help?", "fast-ebay-listings"); ?></h2>
        <p><?php _e("Check out some of the following resources for help and assistance", "fast-ebay-listings"); ?></p>
        <ul>
        <li><a href="https://wordpress.org/plugins/fast-ebay-listings/#faq" target="_blank"><?php _e("Frequently Asked Questions", "fast-ebay-listings"); ?></a></li>
        <li><a href="https://wordpress.org/support/plugin/fast-ebay-listings/" target="_blank"><?php _e("Support forum", "fast-ebay-listings"); ?></a></li>
        <li><a href="<?php echo FUBABY_EBAY_PLUGIN_WEBSITE; ?>" target="_blank"><?php _e("Documentation and support", "fast-ebay-listings"); ?></a></li>
        <li><a href="https://www.fubaby.com/contact-me/" target="_blank"><?php _e("Contact author directly", "fast-ebay-listings"); ?></a></li>
        <li><a href="https://www.fubaby.com/contact-me/" target="_blank"><?php _e("Signup to mailing list for news & updates", "fast-ebay-listings"); ?></a></li>
        </ul>
      </div>
      <div class="fu_ebay_admin_box">
        <h2><?php _e("Liking this plugin?", "fast-ebay-listings"); ?></h2>
        <p><?php _e("If you like this plugin, why not leave a review. Your feedback will be much appreciated", "fast-ebay-listings"); ?></p>
        <a href="https://wordpress.org/support/plugin/fast-ebay-listings/reviews/" target="_blank"><?php _e("Reviews on WordPress.org", "fast-ebay-listings"); ?></a>
        <p><span class="fu_ebay_feedback_stars"><span style="width: 80px"></span></span></p>
        <p><?php _e("If there is something you don't like about this plugin, get in touch and I'll try my best to make things better!", "fast-ebay-listings"); ?></p>
        <a href="https://www.fubaby.com/contact-me/" target="_blank"><?php _e("Contact author directly", "fast-ebay-listings"); ?></a>
      </div>
      <div class="fu_ebay_admin_box">
        <h2><?php _e("Useful Links", "fast-ebay-listings"); ?></h2>
        <ul>
        <li><a href="https://ebay.us/1MpA6E" target="_blank">eBay.com</a></li>
        <li><a href="https://partnernetwork.ebay.com/" target="_blank">eBay Partner Network</a></li>
        </ul>
      </div>   
    </div>
  </div>

  <p><?php
    printf(
      /* translators: %s: name of plugin */
      __("%s is a member of the eBay Developer Program and is a certified eBay Compatible Application. It is not associated with eBay in any way.", "fast-ebay-listings"),
      "Fubaby " . FUBABY_EBAY_PLUGIN_TITLE);
      ?>
  </p>
</div>
<?php
}

function fu_ebay_admin_tab_html(string $currentTab, string $tabName, string $tabTitle)
{
  $class = $currentTab == $tabName ? "nav-tab-active" : "";
  echo "<a href=\"?page=fast-ebay-listings&tab={$tabName}\" class=\"nav-tab {$class}\">{$tabTitle}</a>";
}

////////////////////////////////////////////////////////////////////////////////////////////////////////
//  Callbacks
//
function fu_ebay_options_callback()
{
}

function fu_ebay_options_callback_default()
{
  echo "<p>";
  _e("Enter default search criteria and options to be used site-wide and avoid repeatedly entering these choices on every Fast eBay Listings block, shortcode or widget.", "fast-ebay-listings");
  echo "</p>";

}
function fu_ebay_options_callback_epn()
{
  echo "<p>";
  _e("If you are signed up for the eBay Partner Network and wish to monetize your eBay links fill in your details here.", "fast-ebay-listings");
  echo "</p>";
  echo "<p><em>";
  _e("Unsubscribed plugin users will have 50% of eBay links assigned to the plugin developer to help maintain and support the plugin's development.", "fast-ebay-listings");
  echo "</em></p>";
}

function fu_ebay_options_callback_cosmetic_item()
{
  echo "<p>";
  _e("Tailor the display of eBay items from the Single Item Block and Shortcode", "fast-ebay-listings");
  echo "</p>";
}
function fu_ebay_options_callback_cosmetic_list()
{
  echo "<p>";
  _e("Tailor the display of eBay items from the Search and RSS Feed Blocks and Shortcodes", "fast-ebay-listings");
  echo "</p>";
}
function fu_ebay_options_callback_cosmetic_widget()
{
  echo "<p>";
  _e("Tailor the display of eBay items from search widgets", "fast-ebay-listings");
  echo "</p>";
}

function fu_ebay_definput_callback($args)
{
  // Note the ID and the name attribute of the element should match that of the ID in the call to add_settings_field
  $width = isset($args['width']) ? 'style="width:'.$args['width'].';"' : "";
  $pattern = isset($args['pattern']) ? 'pattern="'.$args['pattern'].'"' : "";
  $html = '<input type="text" id="'.$args['id'].'" name="'.$args['id'].'" value="'.esc_attr(get_option($args['id'])).'" '.$width.' '.$pattern.'/>';
  $html .= fu_ebay_addformlabel($args);
  echo $html;
}

function fu_ebay_intinput_callback($args)
{
  // Note the ID and the name attribute of the element should match that of the ID in the call to add_settings_field
  $width = isset($args['width']) ? 'style="width:'.$args['width'].';"' : "";
  $min = isset($args['min']) ? 'min="'.$args['min'].'"' : "";
  $max = isset($args['max']) ? 'max="'.$args['max'].'"' : "";
  $html = '<input type="number" id="'.$args['id'].'" name="'.$args['id'].'" value="'.intval(get_option($args['id'])).'" '.$width.' '.$min.' '.$max.'/>';
  $html .= fu_ebay_addformlabel($args);
  echo $html;
}

function fu_ebay_checkbox_callback($args)
{
  // Note the ID and the name attribute of the element should match that of the ID in the call to add_settings_field
  $html = '<input type="checkbox" id="'.$args['id'].'" name="'.$args['id'].'"'. checked(true, get_option($args['id']), false) . ' value="1" />';
  $html .= fu_ebay_addformlabel($args);
  echo $html;
}

function fu_ebay_textarea_callback($args) 
{    
  // Note the ID and the name attribute of the element should match that of the ID in the call to add_settings_field  
  $html = '<textarea cols="80" rows="'.(isset($args['rows']) ? $args['rows'] : 4).'" id="'.$args['id'].'" name="'.$args['id'].'">'.get_option($args['id']).'</textarea>';
  $html .= fu_ebay_addformlabel($args);
  echo $html;  
}

function fu_ebay_url_callback($args)
{
  // Note the ID and the name attribute of the element should match that of the ID in the call to add_settings_field
  $width = isset($args['width']) ? 'style="width:'.$args['width'].';"' : "";
  $html = '<input type="url" id="'.$args['id'].'" name="'.$args['id'].'" value="'.esc_attr(get_option($args['id'])).'" '.$width.'/>';
  $html .= fu_ebay_addformlabel($args);
  echo $html;
}

function fu_ebay_category_callback($args)
{
  // Note the ID and the name attribute of the element should match that of the ID in the call to add_settings_field
  $width = isset($args['width']) ? 'style="width:'.$args['width'].';"' : "";
  $pattern = isset($args['pattern']) ? 'pattern="'.$args['pattern'].'"' : "";
  $html = '<input type="text" id="'.$args['id'].'" name="'.$args['id'].'" class="fu_ebay_category_input" value="'.esc_attr(get_option($args['id'])).'" '.$width.' '.$pattern.'/>';
  $html .= fu_ebay_addformlabel($args);
  echo $html;
}

function fu_ebay_globalid_callback($args)
{
  global $ebay_globalid_descriptions;
  echo fu_ebay_addformselect_dict($args, $ebay_globalid_descriptions);
}

function fu_ebay_sellertype_callback($args)
{
  global $fu_seller_type_options;
  echo fu_ebay_addformselect_dict($args, $fu_seller_type_options);
}

function fu_ebay_sortorder_callback($args)
{
  global $ebay_sort_order;
  echo fu_ebay_addformselect_dict($args, $ebay_sort_order);
}

function fu_ebay_slideshowstyle_callback($args)
{
  global $fu_ebay_slideshow_styles;
  echo fu_ebay_addformselect_dict($args, $fu_ebay_slideshow_styles);
}

function fu_ebay_deferredloading_callback($args)
{
  global $fu_deferred_loading_options;
  echo fu_ebay_addformselect_dict($args, $fu_deferred_loading_options);
}

function fu_ebay_colourstyle_callback($args)
{
  global $ebay_colour_options;

  // create a mock up listing.
  $ebayItem = new fuEbayListing;
  $ebayItem->Title = "Title Title Title Title";
  $ebayItem->Arrangement = 0;
  $ebayItem->ItemId = "";
  $ebayItem->Url = "#";
  $ebayItem->EndTime = "Tomorrow";
  $ebayItem->PriceConv = 100.00;
  $ebayItem->GallerySmall = plugins_url(basename(__DIR__) . "/images/mango.jpg");
  $ebayItem->PicLarge = $ebayItem->GallerySmall;
  $ebayItem->PicHuge = $ebayItem->GallerySmall;
  $ebayItem->Active = true;
  $ebayItem->Auction = true;
  $ebayItem->Currency = "&pound;";
  $ebayItem->StoreName = "ACME Co.";

  $html = "";
  $html .= fu_ebay_addformlabel($args);
  
  // First loop to display mock up listing per arrangement option.
  $html .= "<div class=\"fu_ebay_results\"><div class=\"fu_ebay_results_row\">";
  foreach ($ebay_colour_options as $key => $value)
  {
    $html .= "<div class=\"fu_ebay_results_cellcommon fu_ebay_results_cell3\">";
    $html .= "<div style=\"padding: 10px 20px 10px 0px;\">";
    $listingHtml = $ebayItem->GetListingAsHtml(80, 
        fuEbayDisplayFields::ListingDefault,
        false,
        $key);
    // JS call on listing links to select correct radio button.
    $listingHtml = str_replace("href=\"#\"", "href=\"#\" onclick=\"" . esc_attr("javascript:document.getElementById(\"{$args['id']}_{$value}\").checked = true;return false;") . "\"", $listingHtml);
    $html .= $listingHtml;
    $html .= "</div></div>";
  }
  // Second loop of radio form controls per arrangement option.
  $html .= "</div><div class=\"fu_ebay_results_row\" style=\"padding: 20px\">";
  foreach ($ebay_colour_options as $key => $value)
  {
    $html .= "<div class=\"fu_ebay_results_cellcommon fu_ebay_results_cell3\" ><input type=\"radio\" id=\"{$args['id']}_{$value}\" name=\"{$args['id']}\" value=\"{$key}\"";
    $html .= checked($key, get_option($args['id']), false);
    $html .= "><label for=\"{$args['id']}_{$value}\">{$value}</label></div>";
  }
  $html .= "</div></div>";

  echo $html;
}

function fu_ebay_arrangement_callback($args)
{
  $options = array(
    __("Picture centered, title below", "fast-ebay-listings") => 0,
    __("Title above, picture centered", "fast-ebay-listings") => fuEbayArrangement::TitleTop,
    __("Picture left, title right", "fast-ebay-listings") => fuEbayArrangement::ImageLeft,
    __("Title above, picture left", "fast-ebay-listings") => fuEbayArrangement::TitleTop | fuEbayArrangement::ImageLeft,
  );

  $thumbs = array(
    'fubaby_ebayDefArrangementItem' => 'apples.jpg',
    'fubaby_ebayDefArrangementList' => 'bananas.jpg',
    'fubaby_ebayDefArrangementWidget' => 'oranges.jpg',
  );
  
  // create a mock up listing.
  $ebayItem = new fuEbayListing;
  $ebayItem->Title = "Title Title Title Title";
  $ebayItem->ItemId = "";
  $ebayItem->Url = "#";
  $ebayItem->EndTime = "Tomorrow";
  $ebayItem->PriceConv = 100.00;
  $ebayItem->GallerySmall = plugins_url(basename(__DIR__) . "/images/" . $thumbs[$args['id']]);
  $ebayItem->PicLarge = $ebayItem->GallerySmall;
  $ebayItem->PicHuge = $ebayItem->GallerySmall;
  $ebayItem->Active = true;
  $ebayItem->Auction = true;
  $ebayItem->Currency = "&pound;";
  $ebayItem->StoreName = "ACME Co.";

  $html = "";
  $html .= fu_ebay_addformlabel($args);
  
  // First loop to display mock up listing per arrangement option.
  $html .= "<div class=\"fu_ebay_results\"><div class=\"fu_ebay_results_row\">";
  foreach ($options as $key => $value)
  {
    $ebayItem->Arrangement = $value;
    // JS call on listing links to select correct radio button.
    //$ebayItem->Url = esc_attr("javascript:document.getElementById(\"{$args['id']}_{$value}\").checked = true;");
    $html .= "<div class=\"fu_ebay_results_cellcommon fu_ebay_results_cell4\">";
    $html .= "<div style=\"padding: 10px 20px 10px 0px;\">";
    $listingHtml = $ebayItem->GetListingAsHtml(80, fuEbayDisplayFields::ListingDefault);
    $listingHtml = str_replace("href=\"#\"", "href=\"#\" onclick=\"" . esc_attr("javascript:document.getElementById(\"{$args['id']}_{$value}\").checked = true;return false;") . "\"", $listingHtml);
    $html .= $listingHtml;
    $html .= "</div></div>";
  }
  // Second loop of radio form controls per arrangement option.
  $html .= "</div><div class=\"fu_ebay_results_row\" style=\"padding: 20px\">";
  foreach ($options as $key => $value)
  {
    $html .= "<div class=\"fu_ebay_results_cellcommon fu_ebay_results_cell4\" ><input type=\"radio\" id=\"{$args['id']}_{$value}\" name=\"{$args['id']}\" value=\"{$value}\"";
    $html .= checked($value, get_option($args['id']), false);
    $html .= "><label for=\"{$args['id']}_{$value}\">{$key}</label></div>";
  }
  $html .= "</div></div>";

  echo $html;
}

function fu_ebay_displayfields_callback($args)
{
  global $fu_ebay_listing_displayfields;
  $option = (array)get_option($args['id'], fuEbayDisplayFields::ListingDefault);
  
  // Note the ID and the name attribute of the element should match that of the ID in the call to add_settings_field
  $html = "<ul class=\"fu_ebay_admin_checkbox\">";
  foreach ($fu_ebay_listing_displayfields as $field => $desc)
  {
    $html .= '<li><input type="checkbox" id="'.$args['id'].'_'.$field.'" name="'.$args['id'].'[]"'. checked(in_array($field, $option), 1, false) . ' value="'.$field.'" />';
    $html .= '<label for="'.$args['id'].'_'.$field.'">'.$desc.'</label></li>';
  }
  $html .= "<ul>";

  echo $html;
  
}

function fu_ebay_addformselect_arr($args, $arr)
{
  $option = get_option($args['id']);
  $html = '<select id="'.$args['id'].'" name="'.$args['id'].'" >';
  foreach ($arr as $value)
  {
    $html .= '<option value="'.esc_attr($value).'"' . selected($value, $option, false) . '>'.$value.'</option>';
  }
  $html .= '</select>';
  $html .= fu_ebay_addformlabel($args);
  return $html;
}

function fu_ebay_addformselect_dict($args, $dict)
{
  $option = get_option($args['id']);
  $html = '<select id="'.$args['id'].'" name="'.$args['id'].'" >';
  foreach ($dict as $value => $desc)
  {
    $html .= '<option value="'.esc_attr($value).'"' . selected($value, $option, false) . '>'.$desc.'</option>';
  }
  $html .= '</select>';
  $html .= fu_ebay_addformlabel($args);
  return $html;
}

function fu_ebay_addformlabel($args) : string
{
  if (isset($args['label']) && !empty($args['label'])) 
    return'<p><label for="'.$args['id'].'"> '  . $args['label'] . '</label></p>';
  return "";
}

////////////////////////////////////////////////////////////////////////////////////////////////////////
// Handle per user eBay seller id.

add_action( 'show_user_profile', 'fu_ebay_show_profile_fields' );
add_action( 'edit_user_profile', 'fu_ebay_show_profile_fields' );

function fu_ebay_show_profile_fields( $user )
{
  ?>
	<h3><?php _e('eBay Information', 'fast-ebay-listings'); ?></h3>
	<table class="form-table">
		<tr>
			<th><label for="ebayuserid">eBay User</label></th>
			<td>
				<input type="text" name="ebayuserid" id="ebayuserid" value="<?php echo esc_attr( get_the_author_meta( 'ebayuserid', $user->ID ) ); ?>" class="regular-text" /><br />
				<span class="description"><?php _e("Enter your eBay username. Used for eBay searches by post 'author' as the seller.", "fast-ebay-listings"); ?></span>
			</td>
		</tr>
	</table>
<?php 
}


add_action( 'personal_options_update', 'fu_ebay_save_profile_fields' );
add_action( 'edit_user_profile_update', 'fu_ebay_save_profile_fields' );

function fu_ebay_save_profile_fields( $user_id )
{
  if ( !current_user_can( 'edit_user', $user_id ) )
    return false;
  update_user_meta( $user_id, 'ebayuserid', $_POST['ebayuserid'] );
}


?>