<?php

//////////////////////////////////////////////////////////////////////////
//
// Class to query the eBay Browse Get Item
//
//////////////////////////////////////////////////////////////////////////

require_once __DIR__."/apicall.php";

class fuEbayBrowseGetItemApiCall extends fuEbayApiCall
{  
  public $item;
  
  function __construct($item) 
  {
    parent::__construct();
    $this->item = $item;
    $this->arrangement = get_option('fubaby_ebayDefArrangementItem', fuEbayArrangement::ImageLeft);
    if (empty($this->arrangement)) $this->arrangement = fuEbayArrangement::ImageLeft;
  }

  protected function validateArgs(&$message) : bool
  {
    if (!parent::validateArgs($message)) return false;

    if ($this->picWidth <= 0) 
      $this->picWidth = get_option('fubaby_ebayPicWidthItem');	
    
    $this->item = intval($this->item);
    if ($this->item == 0)
    {
      $message = __("Item ID must be an integer.", "fast-ebay-listings");
      return false;
    }
    
    return true;
  } 

  protected function constructRequest()
  {
    $queryParams = array("id" => $this->item);
    $this->requestUri = $this->getEndpoint() . "item?" . http_build_query($queryParams);
    parent::constructRequest();
  }

  protected function createListingGrid($resp)
  {
    $displayFields = count($this->displayFields) > 0 ? $this->displayFields : get_option('fubaby_ebayDefDisplayFieldsItem', fuEbayDisplayFields::ItemDefault);
    array_push($displayFields, fuEbayDisplayFields::EbayLogo);

    if ($resp != null && isset($resp->itemId)) 
    {
      $this->resultCount = 1;
      $ebayItem = $this->initEbayListing($resp);
      $this->result .= $ebayItem->GetListingAsHtml($this->picWidth, $displayFields);
    }
    else 
    {
      $this->result .= "<p>" . get_option('fubaby_ebayEmptySearchMsg', __('No items found', "fast-ebay-listings")) . "</p>";
    }
  }

  protected function initEbayListing($item)
  {
    global $ebay_globalid_currencies;
    
    $ebayItem = $this->createEbayListing();
    $ebayItem->Currency = $ebay_globalid_currencies[$this->globalId];
    $ebayItem->Arrangement = $this->arrangement;

    $ebayItem->ItemId = (string)$item->itemId;
    $ebayItem->Title = (string)$item->title;
    $ebayItem->ShortDescription = isset($item->shortDescription) ? (string)$item->shortDescription : null;
    $ebayItem->Url = (string)$item->itemAffiliateWebUrl;
    $ebayItem->PicHuge = $ebayItem->PicLarge = (string)$item->image->imageUrl;  // 1600px
    $ebayItem->GallerySmall = (string)$item->image->imageUrl;
    $ebayItem->AuctionBids = isset($item->bidCount) ? (int)$item->bidCount : 0;
    $ebayItem->EndTime = isset($item->itemEndDate) ? (string)$item->itemEndDate : "";
    $ebayItem->Active = isset($item->itemEndDate) ? strtotime($ebayItem->EndTime) > time() : true;
    if (!$ebayItem->Active && isset($item->estimatedAvailabilities) )
    {
      if ( $item->estimatedAvailabilities[0]->estimatedAvailabilityStatus == "OUT_OF_STOCK" ||
            $item->estimatedAvailabilities[0]->estimatedAvailableQuantity == 0 )
      {
        $ebayItem->Sold = true;
      }
    }

    $ebayItem->Location = isset($item->itemLocation->city) ? "{$item->itemLocation->city}, {$item->itemLocation->country}" : $item->itemLocation->country;
    $ebayItem->Feedback = (int)$item->seller->feedbackScore;
    $ebayItem->FeedbackPercent = isset($item->seller->feedbackPercentage) ? intval($item->seller->feedbackPercentage) : 100;
    $ebayItem->priorityListing = isset($item->priorityListing) && $item->priorityListing == "true";
    $ebayItem->Condition = isset($item->condition) ? (string)$item->condition : null;

    if (isset($item->buyingOptions))
    {
      if (in_array(fuEbayBuyingOptions::Auction, $item->buyingOptions))
      {
        $ebayItem->Price = $item->currentBidPrice->value;
        $ebayItem->PriceConv = $item->currentBidPrice->value;

        if (in_array(fuEbayBuyingOptions::FixedPrice, $item->buyingOptions))
        {
          $ebayItem->PriceBIN = $item->price->value;
          $ebayItem->PriceBINConv = $item->price->value;
          $ebayItem->ListingType = "AuctionWithBIN"; // Auction + Fixed price = AuctionWithBIN
        }
        else
          $ebayItem->ListingType = "Auction";
      }
      
      // Auctions with BIN/Best Offers
      if ((in_array(fuEbayBuyingOptions::FixedPrice, $item->buyingOptions) && !in_array(fuEbayBuyingOptions::Auction, $item->buyingOptions)) ||
        in_array(fuEbayBuyingOptions::ClassifiedAd, $item->buyingOptions))
      {
        $ebayItem->Price = $ebayItem->PriceBIN = $item->price->value;
        $ebayItem->PriceConv = $ebayItem->PriceBINConv = $item->price->value;
        $ebayItem->ListingType = "FixedPrice";
      }
      
      if (in_array(fuEbayBuyingOptions::BestOffer, $item->buyingOptions))
        $ebayItem->BINBestOffer = true;
    }

    if (isset($item->seller->username))
    {
      if (isset($item->seller->sellerAccountType) && $item->seller->sellerAccountType == fuEbaySellerType::Business)
        $ebayItem->StoreName = (string)$item->seller->username;
      else
        $ebayItem->SellerName = (string)$item->seller->username;
    }
  
    return $ebayItem;
  }
  
  protected function createDeferredLoadingStub()
  {
    $stubId = "fu_ebay_" . parent::$id++;

    $this->result = '
    <div id="'.$stubId.'">' . __("Loading...", "fast-ebay-listings") . '</div>
    <script>
    var $content'.$stubId.' = jQuery("#'.$stubId.'");
    jQuery(document).on("load", jQuery.ajax({
      type : "post",
      url : "'.admin_url('admin-ajax.php').'",
      data : {
          action : "fu_ebay_load_getitem",
          fu_ebay_item : "'.$this->item.'",
          fu_ebay_picwidth : "'.$this->picWidth.'",
          fu_ebay_customId : "'.$this->customId.'",
          nonce : "'.wp_create_nonce("shortcode-getitem").'",
      },
      success : function( response ) {
          $content'.$stubId.'.html( response );
      },
      error: function(e) {
        console.log("'.FUBABY_EBAY_PLUGIN_TITLE.': '.__("deferred loading error:", "fast-ebay-listings").' " + e);
      }
    }));
    </script>
    ';

  }
   
}

// Main AJAX entry function
function fu_ebay_load_getitem() 
{
  if (!check_ajax_referer('shortcode-getitem', 'nonce', false)) 
  {
    $this->errorLog('Nonce check failed');
    die;
  }

  $apicall = new fuEbayBrowseGetItemApiCall($_POST['fu_ebay_item']);
  if (isset($_POST['fu_ebay_picwidth'])) $apicall->picWidth = $_POST['fu_ebay_picwidth'];
  if (isset($_POST['fu_ebay_customId'])) $apicall->customId = $_POST['fu_ebay_customId'];
  echo $apicall->call(true);
  die();
}

add_action( 'wp_ajax_fu_ebay_load_getitem', 'fu_ebay_load_getitem' );
add_action( 'wp_ajax_nopriv_fu_ebay_load_getitem', 'fu_ebay_load_getitem' );