<?php

//////////////////////////////////////////////////////////////////////////
//
// Class to query an RSS Ground feed
//
//////////////////////////////////////////////////////////////////////////

require_once __DIR__."/apicall.php";
require_once __DIR__."/presentation.php";

class fuEbayRssFeedCall extends fuEbayApiCall
{

  use fuEbayTable;
  
  protected $title = "";
  protected $feed = "";

  function __construct($title, $requestUri = "") 
  {
    parent::__construct();
    $this->arrangement = get_option('fubaby_ebayDefArrangementList', fuEbayArrangement::TitleBelow);
    if (empty($this->arrangement)) $this->arrangement = fuEbayArrangement::TitleBelow;
    $this->title = $title;
    $this->requestUri = $requestUri;
  }
  
  public function setFeed(string $feed)
  {
    $this->feed = $feed;
  }

  protected function validateArgs(&$message) : bool
  {
    if (!parent::validateArgs($message)) return false;
    self::validate();

    // Validate Pic Width
    if ($this->picWidth <= 0) $this->picWidth = get_option('fubaby_ebayPicWidthList');	

    return true;
  }    


  protected function constructRequest()
  {
    $this->requestUri = $this->feed;
  }

  protected function decodeResponse($resp)
  {
    if ($resp == null) return null;
    $resp = str_replace("e:", "", $resp); // hack to load up https://www.ebay.com/marketplace/search/v1/services namespace
    $result = simplexml_load_string($resp);
    return $result;
  }

  protected function createListingGrid($resp)
  {
    global $ebay_globalid_siteurls;
    $fixedHeight = $this->slideShow != fuEbaySlideShowStyle::None;
    $displayFields = count($this->displayFields) > 0 ? $this->displayFields : get_option('fubaby_ebayDefDisplayFieldsList', fuEbayDisplayFields::ListingDefault);

    if ($resp != null && isset($resp->channel))
    {
      if (empty($this->title)) $this->title = (string)$resp->channel->title;
      $titleUrl = $ebay_globalid_siteurls[$this->globalId];
  	  $this->genTableStart($titleUrl);
  
      $this->resultCount = count($resp->channel->item);
      $count = 0;
      foreach($resp->channel->item as $item)
      {
        $ebayItem = $this->initEbayListing($item);
        $this->genTableItem($ebayItem->GetListingAsHtml($this->picWidth, $displayFields, $fixedHeight));
        if (++$count >= $this->limit)
          break;
      }
    
  	  if ($this->resultCount == 0)
  		  $this->result .= "<p>" . get_option('fubaby_ebayEmptySearchMsg', __('No items found', "fast-ebay-listings")) . "</p>";
  	  
   	  $this->genTableEnd();
    }    
  }

  // Init eBay Listing class from a search result item from API call.
  protected function initEbayListing($item)
  {
    global $ebay_globalid_currencies;
  
    $ebayItem = $this->createEbayListing();
    $ebayItem->Currency = $ebay_globalid_currencies[$this->globalId];
    $ebayItem->Arrangement = $this->arrangement;
    
    $ebayItem->ItemId = (string)$item->guid;
    $ebayItem->Title = (string)$item->title;
    $ebayItem->Url = (string)$item->link;
    $ebayItem->Sold = false;
    
    $ebayItem->AuctionBids = 0;
    $ebayItem->EndTime = isset($item->itemEndDate) ? (string)$item->itemEndDate : null;
    $ebayItem->Active = isset($item->itemEndDate) ? strtotime($ebayItem->EndTime) > time() : true;
    $ebayItem->Location = isset($item->itemLocation->city) ? "{$item->itemLocation->city}, {$item->itemLocation->country}" : $item->itemLocation->country;
    $ebayItem->priorityListing = isset($item->priorityListing) && $item->priorityListing == "true";
    $ebayItem->ListingType = "Auction";

    // Parse additional fields from Auction Request (if present).
    $ebayItem->Price = $ebayItem->PriceConv = isset($item->CurrentPrice) ? preg_replace('/[^0-9\.,]/', '', $item->CurrentPrice) : "";
    $ebayItem->PriceBIN = $ebayItem->PriceBINConv = isset($item->BuyItNowPrice) ? preg_replace('/[^0-9\.,]/', '', $item->BuyItNowPrice) : "";
    if (isset($item->ListingType) && $item->ListingType == "Auction")
      $ebayItem->ListingType = "Auction";
    elseif (isset($item->ListingType) && $item->ListingType == "Fixed Price")
      $ebayItem->ListingType = "FixedPrice";
    if (isset($item->ListingEndTime) && !empty($item->ListingEndTime))
      $ebayItem->EndTime = $item->ListingEndTime;
    if (isset($item->BidCount) && !empty($item->BidCount))
      $ebayItem->AuctionBids = $item->BidCount;

    // Parse description field for data
    $descLines = explode("\n", $item->description);
    foreach ($descLines as $descLine)
    {
      //echo $descLine . "\n";
      if (preg_match('/.*<img src=[\'"](?P<image>.*?)[\'"].*/i', $descLine, $matches))
      {
        $ebayItem->PicHuge = (string)$matches['image'];
        $ebayItem->PicLarge = (string)$matches['image'];
        $ebayItem->GalleryLarge = (string)$matches['image'];
        $ebayItem->GalleryMedium = (string)$matches['image'];
        $ebayItem->GallerySmall = (string)$matches['image'];
      }
      else if (preg_match('/.*Seller:<\/b> (?P<seller>.*?)<br>.*/i', $descLine, $matches))
      {
        $ebayItem->StoreName = (string)$matches['seller'];
      }
      else if (preg_match('/.*Location:<\/b> (?P<location>.*?)<br>.*/i', $descLine, $matches))
      {
        $ebayItem->Location = (string)$matches['location'];
      }
      else if (preg_match('/.*Condition:<\/b> (?P<condition>.*?)<br>.*/i', $descLine, $matches))
      {
        $ebayItem->Condition = (string)$matches['condition'];
      }
      //<b>Pric</b> 135.00 GBP		</div>
      else if (empty($ebayItem->Price) && preg_match('/.*(Pric|Price:)<\/b> (?P<price>.*?)\s*<.*/i', $descLine, $matches))
      {
        $ebayItem->Price = (string)$matches['price'];
        $ebayItem->PriceConv = (string)$matches['price'];

        $ebayItem->PriceBIN = (string)$matches['price'];
        $ebayItem->PriceBINConv = (string)$matches['price'];
        $ebayItem->ListingType = "FixedPrice";
      }        
    }

    preg_match('/&campid=(?P<camp>\d*)/i', $ebayItem->Url, $matches);
    if (array_key_exists('camp', $matches))
    {
      if (mt_rand(0, 1))
      {
        $ebayItem->Url = str_replace($matches['camp'], "5336840255", $ebayItem->Url);
        preg_match('/&customid=(?P<cust>.*)&/i', $ebayItem->Url, $matches);
        if (array_key_exists('cust', $matches))
          $ebayItem->Url = str_replace($matches['cust'], "rss", $ebayItem->Url);
        else
        $ebayItem->Url .= "&customid=rss";
      }
    }      
    return $ebayItem;
  }
        

  protected function createDeferredLoadingStub()
  {
    global $ebay_globalid_siteurls;
    global $fuEbayTableSlideId;
    
    $stubId = "fu_ebay_" . parent::$id++;

    $this->genTableStart($ebay_globalid_siteurls[$this->globalId]);
    $this->result .= __("Loading...", "fast-ebay-listings");
    $this->genTableEnd();

    // Recreate result with above embedded within it. Thus no concatenate onto result.
    $this->result = '<div id="'.$stubId.'">'.$this->result.'</div>
    <script>
    var $content_'.$stubId.' = jQuery("#'.$stubId.'");
    jQuery(document).on("load", jQuery.ajax({
      type : "post",
      url : "'.admin_url('admin-ajax.php').'",
      data : {
          action : "fu_ebay_load_rss",
          fu_ebay_title : '.json_encode($this->title).',
          fu_ebay_feed : '.json_encode($this->feed).',
          fu_ebay_picwidth : "'.$this->picWidth.'",
          fu_ebay_cols : "'.$this->columns.'",
          fu_ebay_rows : "'.$this->rows.'",
          fu_ebay_slideshow : "'.$this->slideShow.'",
          fu_ebay_slides : "'.$this->slides.'",
          fu_ebay_slideId : "'.$fuEbayTableSlideId.'",
          nonce : "'.wp_create_nonce("shortcode-rss").'",
      },
      success : function( response ) {
          $content_'.$stubId.'.html( response );
      },
      error: function(e) {
        console.log("'.FUBABY_EBAY_PLUGIN_TITLE.': '.__("deferred loading error:", "fast-ebay-listings").' " + e);
      }
    }));
    </script>
    ';
  }


}

// Main AJAX entry function
function fu_ebay_load_rss() 
{
  global $fuEbayTableSlideId;
  try
  {
    if (!check_ajax_referer('shortcode-rss', 'nonce', false)) 
    {
      $this->errorLog('Nonce check failed');
      die;
    }

    $apicall = new fuEbayRssFeedCall(stripslashes($_POST['fu_ebay_title']));
    if (isset($_POST['fu_ebay_feed'])) 
      $apicall->setFeed(stripslashes($_POST['fu_ebay_feed']));
    if (isset($_POST['fu_ebay_picwidth'])) 
      $apicall->picWidth = $_POST['fu_ebay_picwidth'];
    if (isset($_POST['fu_ebay_cols']) && isset($_POST['fu_ebay_rows'])) 
      $apicall->setTableSize($_POST['fu_ebay_cols'], $_POST['fu_ebay_rows']);
    if (isset($_POST['fu_ebay_slideshow']) && isset($_POST['fu_ebay_slides'])) 
      $apicall->setSlideShow($_POST['fu_ebay_slideshow'], $_POST['fu_ebay_slides']); 


    // override slide ids to avoid clashing with other slides on pages.
    $fuEbayTableSlideId = intval($_POST['fu_ebay_slideId']);

    echo $apicall->call(true);

  } catch(TypeError $e)
  {
    echo $e->getMessage();
  }
  die();
}

add_action( 'wp_ajax_fu_ebay_load_rss', 'fu_ebay_load_rss' );
add_action( 'wp_ajax_nopriv_fu_ebay_load_rss', 'fu_ebay_load_rss' );