( function( wp ) {
	var el = wp.element.createElement;
	var __ = wp.i18n.__;

	/**
	 * Import stuff for the Inspector Controls 
	 */
	var InspectorControls = wp.blockEditor.InspectorControls;
	var PlainText = wp.blockEditor.PlainText;
	var PanelBody = wp.components.PanelBody;
	var SelectControl = wp.components.SelectControl;
	var TextControl = wp.components.TextControl;
	
	/**
	 * Every block starts by registering a new block type definition.
	 */
	wp.blocks.registerBlockType( 'fast-ebay-listings/feedback', {

		/**
		 * The edit function describes the structure of your block in the context of the editor.
		 * This represents what the editor will render when the block is used.
		 *
		 * @param {Object} [props] Properties passed from the editor.
		 * @return {Element}       Element to render.
		 */
		edit: function( props ) {
			var attributes = props.attributes;
			var seller = attributes.seller != null && attributes.seller.length > 0 ? attributes.seller : __( '' );
			var customid = attributes.customid != null && attributes.customid.length > 0 ? attributes.customid : '';
			
			/* Event handlers */

			/* Return the edit content */
			return [
					!! props.isSelected && el(InspectorControls, { key: 'inspector' },
						el( 'div', { className: 'components-block-description' }),
						
						el(PanelBody, 
								{ 
									title: __( 'Search Criteria', 'fast-ebay-listings' ),
									initialOpen: true
								},
								el(TextControl,
									{
										type: 'text',
										label: __( 'Seller', 'fast-ebay-listings' ),
										placeholder: fuScriptBlock.ebayDefSeller,
										value: seller,
										onChange: function( value ) {
										    props.setAttributes( { seller: value } );
										},
									}
								),
							),												
						el(PanelBody, 
							{ 
								title: __( 'Presentation', 'fast-ebay-listings' ),
								initialOpen: true 
							},
							el(TextControl,
								{
									type: 'number',
									label: __( 'Max Feedback Comments', 'fast-ebay-listings' ),
									value: props.attributes.limit,
									onChange: function ( value ) {
										props.setAttributes( { limit: value } );
									},
								}
							)
						),
            el(PanelBody, 
              { 
                title: __( 'eBay Partner Network', 'fast-ebay-listings' ),
                initialOpen: true 
              },
              el(TextControl,
                {
                  type: 'text',
                  label: __( 'Custom ID', 'fast-ebay-listings' ),
                  placeholder: fuScriptBlock.ebayDefCustomID,
                  value: customid,
                  onChange: function ( value ) {
                    props.setAttributes( { customid: value } );
                  },
                }
              ),						
            )
  
					),		
					el( 'div', 
						{ className: 'fu_ebay_results_container' }
						),
						el( 'img',
							{ src: fuScriptBlock.pluginsUrl + '/blocks/images/ebayfeedbackpanel.jpg', width: '701', height: '126' } 
						),						
					];
		},

		/**
		 * The save function defines the way in which the different attributes should be combined
		 * into the final markup, which is then serialized by Gutenberg into `post_content`.
		 *
		 * @return {Element}       Element to render.
		 */
		save: function( props ) {
			// Rendering in PHP.
			return null;
		}
	} );
} )(
	window.wp
);
