( function( wp ) {
	var el = wp.element.createElement;
	var __ = wp.i18n.__;
	
	/**
	 * Import stuff for the Inspector Controls 
	 */
	var InspectorControls = wp.blockEditor.InspectorControls;
	var PlainText = wp.blockEditor.PlainText;
	var PanelBody = wp.components.PanelBody;
	var SelectControl = wp.components.SelectControl;
	var TextControl = wp.components.TextControl;
	var CheckboxControl = wp.components.CheckboxControl;
	
	/**
	 * Every block starts by registering a new block type definition.
	 * @see https://wordpress.org/gutenberg/handbook/block-api/
	 */
	wp.blocks.registerBlockType( 'fast-ebay-listings/rssfeed', {
    
		/**
		 * The edit function describes the structure of your block in the context of the editor.
		 * This represents what the editor will render when the block is used.
		 * @see https://wordpress.org/gutenberg/handbook/block-edit-save/#edit
		 *
		 * @param {Object} [props] Properties passed from the editor.
		 * @return {Element}       Element to render.
		 */
		edit: function( props ) {
			var attributes = props.attributes;
			var title = attributes.title != null && attributes.title.length > 0 ? attributes.title : "";
			var feed = attributes.feed != null && attributes.feed.length > 0 ? attributes.feed : '';
			
			/* Return the edit content */
			return [
					!! props.isSelected && el(InspectorControls, { key: 'inspector' },
						el( 'div', { className: 'components-block-description' }),
						
						el(PanelBody, 
							{ 
								title: __( 'Search Criteria', 'fast-ebay-listings' ),
								initialOpen: false
							},
							el(TextControl,
									{
										type: 'text',
										label: __( 'RSS Feed URI (e.g. from RSSGround.com or AuctionRequest)', 'fast-ebay-listings' ),
										value: feed,
										onChange: function ( value ) {
											props.setAttributes( { feed: value } );
										},
									}
								),
						),
					el(PanelBody, 
						{ 
							title: __( 'Presentation', 'fast-ebay-listings' ),
							initialOpen: false 
						},
            el(TextControl,
							{
								type: 'number',
								label: __( 'Picture Width', 'fast-ebay-listings' ),
                placeholder: fuScriptBlock.ebayPicWidthList,
								value: props.attributes.picwidth,
								onChange: function ( value ) {
									props.setAttributes( { picwidth: value } );
								},
							}
						),
						el(TextControl,
							{
								type: 'number',
								label: __( 'Result Columns', 'fast-ebay-listings' ),
                placeholder: fuScriptBlock.ebayDefColumns,
								value: props.attributes.columns,
								onChange: function ( value ) {
									props.setAttributes( { columns: value } );
								},
							}
						),									
						el(TextControl,
							{
								type: 'number',
								label: __( 'Results Rows', 'fast-ebay-listings' ),
                placeholder: fuScriptBlock.ebayDefRows,
								value: props.attributes.rows,
								onChange: function ( value ) {
									props.setAttributes( { rows: value } );
								},
							}
						),
						el(SelectControl,
							{
								type: 'text',
								label: __( 'Slideshow Style', 'fast-ebay-listings' ),
								value: props.attributes.slideshow,
								onChange: function ( value ) {
									props.setAttributes( { slideshow: value } );
								},
								options: [						           
										{label: __( 'Settings Default', 'fast-ebay-listings'), value: ''},
										{label: __( 'None', 'fast-ebay-listings'), value: 'None'},
										{label: __( 'Manual', 'fast-ebay-listings'), value: 'Manual'},
										{label: __( 'Auto', 'fast-ebay-listings'), value: 'Auto'},
									],
							}
						),			
						el(TextControl,
							{
								type: 'number',
								label: __( 'Number of slides', 'fast-ebay-listings' ),
                placeholder: fuScriptBlock.ebayDefNumSlides,
								value: props.attributes.slides,
								onChange: function ( value ) {
									props.setAttributes( { slides: value } );
								},
							}
						)	
					),
					),

					el( 'div', 
						{ className: 'fu_ebay_results_container' },
						el( 'div', 
							{ className: 'fu_ebay_results_title' },						
							el( 'a',
								{ href: '#' },
								el( 'img',
									{ src: fuScriptBlock.pluginsUrl + '/US/Right Now 108x45.gif', width: '108', height: '45' } 
									)),
							el( 'a',
								{ href: '#' },										
								el( PlainText, 
									{
										className: 'fu_ebay_results_title_editor',
										placeholder: __( 'Results Title' ),
										value: title,
										onChange: function( value ) {
										    props.setAttributes( { title: value } );
										  }										  
									}
								)
							)			
						)
					),
					el( 'img',
						{ src: fuScriptBlock.pluginsUrl + '/blocks/images/ebaysearchpanel.jpg', width: '644', height: '78' } 
					),						
				];
		},

		/**
		 * The save function defines the way in which the different attributes should be combined
		 * into the final markup, which is then serialized by Gutenberg into `post_content`.
		 * @see https://wordpress.org/gutenberg/handbook/block-edit-save/#save
		 *
		 * @return {Element}       Element to render.
		 */
		save: function( props ) {
			// Rendering in PHP.
			return null;
		}
	} );
} )(
	window.wp
);
