( function( wp ) {
	var el = wp.element.createElement;
	var __ = wp.i18n.__;
  
	/**
	 * Import stuff for the Inspector Controls 
	 */
	var InspectorControls = wp.blockEditor.InspectorControls;
	var PlainText = wp.blockEditor.PlainText;
	var PanelBody = wp.components.PanelBody;
	var SelectControl = wp.components.SelectControl;
	var TextControl = wp.components.TextControl;
	var CheckboxControl = wp.components.CheckboxControl;
	
	/**
	 * Every block starts by registering a new block type definition.
	 * @see https://wordpress.org/gutenberg/handbook/block-api/
	 */
	wp.blocks.registerBlockType( 'fast-ebay-listings/search', {

		/**
		 * The edit function describes the structure of your block in the context of the editor.
		 * This represents what the editor will render when the block is used.
		 *
		 * @param {Object} [props] Properties passed from the editor.
		 * @return {Element}       Element to render.
		 */
		edit: function( props ) {
			var attributes = props.attributes;
			var title = attributes.title != null && attributes.title.length > 0 ? attributes.title : "";
			var query = attributes.query != null && attributes.query.length > 0 ? attributes.query : '';
			var customid = attributes.customid != null && attributes.customid.length > 0 ? attributes.customid : '';
      var buyingOptionsArr = (attributes.buyingoptions != null && attributes.buyingoptions.length > 0 ? attributes.buyingoptions : 'FIXED_PRICE|AUCTION|BEST_OFFER').split("|");
      var buyingOptionFixedPrice = buyingOptionsArr.includes('FIXED_PRICE');
      var buyingOptionAuction = buyingOptionsArr.includes('AUCTION');
      var buyingOptionBestOffer = buyingOptionsArr.includes('BEST_OFFER');
			
			/* Event handlers */
      function onBuyingOptionsCheckChange(value) {
        var buyingOptionsArr = (attributes.buyingoptions != null && attributes.buyingoptions.length > 0 ? attributes.buyingoptions : 'FIXED_PRICE|AUCTION|BEST_OFFER').split("|");
        const index = buyingOptionsArr.indexOf(this.toString());
        if (index > -1) buyingOptionsArr.splice(index, 1); // Remove the item
        if (value) buyingOptionsArr.push(this.toString()); // add if checked.
        props.setAttributes( {buyingoptions: buyingOptionsArr.join("|")} );
      }

			/* Return the edit content */
			return [
					!! props.isSelected && el(InspectorControls, { key: 'inspector' },
						el( 'div', { className: 'components-block-description' }),
						
						el(PanelBody, 
							{ 
								title: __( 'Search Criteria', 'fast-ebay-listings' ),
								initialOpen: false
							},
							el(TextControl,
									{
										type: 'text',
										label: __( 'Search Query', 'fast-ebay-listings' ),
										//placeholder: __( 'eBay search query keywords', 'fast-ebay-listings' ),
										value: query,
										onChange: function ( value ) {
											props.setAttributes( { query: value } );
										},
									}
								),
							el(TextControl,
								{
									type: 'text',
									label: __( 'Category ID', 'fast-ebay-listings' ),
                  placeholder: fuScriptBlock.ebayDefCategory,
									value: props.attributes.category,
                  class: 'fu_ebay_category_input components-text-control__input',
									onChange: function ( value ) {
										props.setAttributes( { category: value } );
									},
								}
							),
							el(TextControl,
								{
									type: 'text',
									label: __( 'Seller', 'fast-ebay-listings' ),
                  placeholder: fuScriptBlock.ebayDefSeller,
									value: props.attributes.seller,
									onChange: function ( value ) {
										props.setAttributes( { seller: value } );
									},
								}
							),
							el(SelectControl,
								{
									type: 'text',
									label: __( 'Seller Type', 'fast-ebay-listings' ),
									value: props.attributes.sellertype,
									onChange: function ( value ) {
										props.setAttributes( { sellertype: value } );
									},
									options: [						           
										{label: __( 'Settings Default', 'fast-ebay-listings' ), value: ''},
										{label: __( 'Any', 'fast-ebay-listings' ), value: 'BUSINESS|INDIVIDUAL'},
										{label: __( 'Business', 'fast-ebay-listings' ), value: 'BUSINESS'},
										{label: __( 'Individual', 'fast-ebay-listings' ), value: 'INDIVIDUAL'},
									],
								}
							),
              el('div', 
                { className: 'fu_ebay_label_editor' },
								__( 'Buying Options', 'fast-ebay-listings' ),
							),	
              el(CheckboxControl,
								{
									label: __( 'Fixed Price', 'fast-ebay-listings' ),
									checked: buyingOptionFixedPrice,
									onChange: onBuyingOptionsCheckChange.bind( "FIXED_PRICE" ),
                  className: 'fu_ebay_checkbox_editor',
								}
							),	
              el(CheckboxControl,
								{
									label: __( 'Auction', 'fast-ebay-listings' ),
									checked: buyingOptionAuction,
									onChange: onBuyingOptionsCheckChange.bind( "AUCTION" ),
                  className: 'fu_ebay_checkbox_editor',
								}
							),	
              el(CheckboxControl,
								{
									label: __( 'Best Offer', 'fast-ebay-listings' ),
									checked: buyingOptionBestOffer,
									onChange: onBuyingOptionsCheckChange.bind( "BEST_OFFER" ),
								}
							),	
              el(TextControl,
								{
									type: 'number',
									label: __( 'Min Price', 'fast-ebay-listings' ),
									value: props.attributes.minprice,
									onChange: function ( value ) {
										props.setAttributes( { minprice: value } );
									},
								}
							),							
							el(TextControl,
								{
									type: 'number',
									label: __( 'Max Price', 'fast-ebay-listings' ),
									value: props.attributes.maxprice,
									onChange: function ( value ) {
										props.setAttributes( { maxprice: value } );
									},
								}
							),
						),
					el(PanelBody, 
						{ 
							title: __( 'Presentation', 'fast-ebay-listings' ),
							initialOpen: false 
						},
            el(SelectControl,
              {
                type: 'text',
                label: __( 'Sorting', 'fast-ebay-listings' ),
                value: props.attributes.sort,
                onChange: function ( value ) {
                  props.setAttributes( { sort: value } );
                },
                options: [						           
                  {label: __( 'Settings Default', 'fast-ebay-listings' ), value: ''},
                  {label: __( 'Best Match', 'fast-ebay-listings' ), value: 'BestMatch'},
                  {label: __( 'Fewest Bids First', 'fast-ebay-listings' ), value: 'BidCountFewest'},
                  {label: __( 'Most Bids First', 'fast-ebay-listings' ), value: 'BidCountMost'},
                  {label: __( 'Highest Price First', 'fast-ebay-listings' ), value: 'CurrentPriceHighest'},
                  {label: __( 'Nearest First', 'fast-ebay-listings' ), value: 'DistanceNearest'},
                  {label: __( 'Ending Soonest', 'fast-ebay-listings' ), value: 'EndTimeSoonest'},
                  {label: __( 'Highest Price + P&P First', 'fast-ebay-listings' ), value: 'PricePlusShippingHighest'},
                  {label: __( 'Lowest Price + P&P First', 'fast-ebay-listings' ), value: 'PricePlusShippingLowest'},
                  {label: __( 'Newest First', 'fast-ebay-listings' ), value: 'StartTimeNewest'}
                ],
              }
            ),
            el(TextControl,
							{
								type: 'number',
								label: __( 'Picture Width', 'fast-ebay-listings' ),
                placeholder: fuScriptBlock.ebayPicWidthList,
								value: props.attributes.picwidth,
								onChange: function ( value ) {
									props.setAttributes( { picwidth: value } );
								},
							}
						),
						el(TextControl,
							{
								type: 'number',
								label: __( 'Result Columns', 'fast-ebay-listings' ),
                placeholder: fuScriptBlock.ebayDefColumns,
								value: props.attributes.columns,
								onChange: function ( value ) {
									props.setAttributes( { columns: value } );
								},
							}
						),									
						el(TextControl,
							{
								type: 'number',
								label: __( 'Results Rows', 'fast-ebay-listings' ),
                placeholder: fuScriptBlock.ebayDefRows,
								value: props.attributes.rows,
								onChange: function ( value ) {
									props.setAttributes( { rows: value } );
								},
							}
						),
						el(SelectControl,
							{
								type: 'text',
								label: __( 'Slideshow Style', 'fast-ebay-listings' ),
								value: props.attributes.slideshow,
								onChange: function ( value ) {
									props.setAttributes( { slideshow: value } );
								},
								options: [						           
										{label: __( 'Settings Default', 'fast-ebay-listings'), value: ''},
										{label: __( 'None', 'fast-ebay-listings'), value: 'None'},
										{label: __( 'Manual', 'fast-ebay-listings'), value: 'Manual'},
										{label: __( 'Auto', 'fast-ebay-listings'), value: 'Auto'},
									],
							}
						),			
						el(TextControl,
							{
								type: 'number',
								label: __( 'Number of slides', 'fast-ebay-listings' ),
                placeholder: fuScriptBlock.ebayDefNumSlides,
								value: props.attributes.slides,
								onChange: function ( value ) {
									props.setAttributes( { slides: value } );
								},
							}
						)	
					),
          el(PanelBody, 
            { 
              title: __( 'eBay Partner Network', 'fast-ebay-listings' ),
              initialOpen: false 
            },
            el(TextControl,
              {
                type: 'text',
                label: __( 'Custom ID', 'fast-ebay-listings' ),
                placeholder: fuScriptBlock.ebayDefCustomID,
                value: customid,
                onChange: function ( value ) {
                  props.setAttributes( { customid: value } );
                },
              }
            ),						
          )
					),

					el( 'div', 
						{ className: 'fu_ebay_results_container' },
						el( 'div', 
							{ className: 'fu_ebay_results_title' },						
							el( 'a',
								{ href: '#' },
								el( 'img',
									{ src: fuScriptBlock.pluginsUrl + '/US/Right Now 108x45.gif', width: '108', height: '45' } 
									)),
							el( 'a',
								{ href: '#' },										
								el( PlainText, 
									{
										className: 'fu_ebay_results_title_editor',
										placeholder: __( 'Results Title' ),
										value: title,
										onChange: function( value ) {
										    props.setAttributes( { title: value } );
										  }										  
									}
								)
							)			
						)
					),
					el( 'img',
						{ src: fuScriptBlock.pluginsUrl + '/blocks/images/ebaysearchpanel.jpg', width: '644', height: '78' } 
					),						
				];
		},

		/**
		 * The save function defines the way in which the different attributes should be combined
		 * into the final markup, which is then serialized by Gutenberg into `post_content`.
		 *
		 * @return {Element}       Element to render.
		 */
		save: function( props ) {
			// Rendering in PHP.
			return null;
		}
	} );
} )(
	window.wp
);
