<?php
//////////////////////////////////////////////////////////////////////////
//
// Class to store a single ebay listing
//
//////////////////////////////////////////////////////////////////////////

require_once __DIR__."/utilities.php";

class fuEbayListing
{
  const DebugPrintOuts = FALSE;
  
  public function __construct()
  {
    $this->Active = TRUE;
    $this->Sold = FALSE;
    $this->AuctionBids= 0;
    $this->BINBestOffer = FALSE;
    $this->Feedback = null;
    $this->FeedbackPercent = 100;
  }  
  
  protected function GetEbayImage($picWidth)
  {
  	$picWidth = intval($picWidth);
  	if ( $picWidth <= 0 )
  		$picWidth = get_option('fubaby_ebayPicWidth');
  	
    if ($picWidth > 1000 && !empty($this->PicHuge))
      $picUrl = $this->PicHuge;
    else if ($picWidth > 225 && !empty($this->PicLarge))
      $picUrl = $this->PicLarge;
    else if ($picWidth > 96 && !empty($this->GalleryLarge))
      $picUrl = $this->GalleryLarge;
    else if ($picWidth > 80 && !empty($this->GalleryMedium))
      $picUrl = $this->GalleryMedium;
    else
      $picUrl = $this->GallerySmall;
  	
    if (empty($picUrl))
      return "";
        
  	$result = "<img src=\"" . htmlentities(fuEbayUtils::GetSecureUrl($picUrl)) . "\" ";
  	$result .= "alt=\"" . htmlentities($this->Title) . "\" ";
  	$result .= "title=\"" . htmlentities($this->Title) . "\" ";
  	$result .= "/>";
  	
  	return fuEbayUtils::GetEbayLink($this->Url, $this->Title, $this->ItemId, $result);
  }
  
  protected function GetEndTime()
  {
  	// get time difference in seconds.
  	$dateEnd = strtotime($this->EndTime);
    $diff = $dateEnd - time();
    
    $days = floor($diff / (60*60*24));
    $hours = floor(($diff - ($days*60*60*24)) / (60*60));
    $mins = floor(($diff - ($days*60*60*24) - ($hours*60*60)) / 60);
    
    if ( $diff > 60 )
    {
      $duration = "";
    	if ($days > 0) $duration .= $days . "d ";
    	if ($hours > 0) $duration .= $hours . "h ";
      if ($days == 0 && $mins > 0) $duration .= $mins . "m ";
      return sprintf(
        // translators: %s: duration of time left */
        __("Ends in %s", "fast-ebay-listings"),
        $duration);
    }
    else if ( $diff >= 0 )
      return sprintf(
        // translators: %s: duration of time left */
        __("Ends in %s", "fast-ebay-listings"),
        "{$diff}s ");
    else
      return sprintf(
        // translators: %s: date sale ended */
        __("Ended %s", "fast-ebay-listings"),
        date_i18n("F j, Y, g:i a", $dateEnd));
  }
  
 
  //! Func to write out a listing. 
  public function GetListingAsHtml(int $picWidth, array $displayFields, bool $fixedHeight = false, string $colourStyle = "")
  { 
    global $ebay_colour_class;
    $results = "";
    
    // Frame
    if (empty($colourStyle)) $colourStyle = get_option('fubaby_ebayColourStyle', "Default");
    $results .= "<div class=\"fu_ebay_listing_frame {$ebay_colour_class[$colourStyle]}\">\n";
     
    $results .= "<div class=\"fu_ebay_listing_item\">\n";
    
    // Top Title
    if ( in_array(fuEbayDisplayFields::Title, $displayFields) && $this->Arrangement & fuEbayArrangement::TitleTop )		
      $results .= "<h6 class=\"fu_ebay_title\">" . fuEbayUtils::GetEbayLink($this->Url, $this->Title, $this->ItemId) ."</h6>\n";

    if ( $this->Arrangement & fuEbayArrangement::ImageLeft )
      $results .= $this->GetListingLeftImage($picWidth, $displayFields, $fixedHeight);
    else
      $results .= $this->GetListingCentreImage($picWidth, $displayFields, $fixedHeight);

    // Description
    if ( in_array(fuEbayDisplayFields::ShortDesc, $displayFields) && !empty($this->ShortDescription) )		
      $results .= "<div class=\"fu_ebay_desc\">" . $this->ShortDescription ."</div>\n";

    if ( in_array(fuEbayDisplayFields::VisitLink, $displayFields) )
      $results .= "<div class=\"fu_ebay_visitlink\">" . fuEbayUtils::GetEbayLink($this->Url, $this->Title, $this->ItemId, "&rarr; " . __("View on eBay", "fast-ebay-listings")) . "</div>\n";

    $results .= "</div>\n"; //fu_ebay_listing_item
    $results .= "</div>\n"; // fu_ebay_listing_frame
           
    return $results;
  }	
  
  protected function GetListingCentreImage(int $picWidth, array $displayFields, bool $fixedHeight)
  { 
    $height = $fixedHeight ? "height" : "max-height";
    $results = "<div class=\"fu_ebay_listing_contentwrapper_centre\">\n";   
   
    // Not left image.
    if ( in_array(fuEbayDisplayFields::Image, $displayFields) )
    {
      $results .= "<div class=\"fu_ebay_listing_img\" style=\"width:{$picWidth}px;{$height}:{$picWidth}px\">" . 
        $this->GetEbayImage($picWidth) . 
        "</div>\n";
    }
    
    // Content box.
    $results .= "<div class=\"fu_ebay_listing_content_centre\">";
    
    $results .= $this->GetListingContent($picWidth, $displayFields);

    $results .= "</div>\n"; // fu_ebay_listing_content_centre
    
    $results .= "</div>\n"; // fu_ebay_listing_contentwrapper_centre
    
    return $results;
  }

  protected function GetListingLeftImage(int $picWidth, array $displayFields, bool $fixedHeight)
  { 
    global $ebay_globalid_currencies;
    $height = $fixedHeight ? "height" : "max-height";
    
    $results = "";
    $results .= "<div class=\"fu_ebay_listing_contentwrapper_left\">\n";   
    
    // Image
    if ( in_array(fuEbayDisplayFields::Image, $displayFields) )
    {
      $results .= "<div class=\"fu_ebay_listing_img_left\" style=\"width:{$picWidth}px;{$height}:{$picWidth}px\">";
      if ( $this->Arrangement == fuEbayArrangement::ImageLeft )
        $results .= "<h6 class=\"fu_ebay_title\">";
      $results .= $this->GetEbayImage($picWidth);
      if ( $this->Arrangement == fuEbayArrangement::ImageLeft )
        $results .= "</h6>"; 
      $results .= "</div>\n";
    }

    // Content box.
    $results .= "<div class=\"fu_ebay_listing_content_left\">\n";
    
    $results .= $this->GetListingContent($picWidth, $displayFields);

    $results .= "</div>\n"; // fu_ebay_listing_content_left
     
    $results .= "</div>\n"; // fu_ebay_listing_contentwrapper_left

    return $results;
  }

  protected function GetListingContent(int $picWidth, array $displayFields)
  { 
    global $ebay_globalid_currencies;
    $results = "";

    // Display of the 'Right now on eBay' logo is mandatory as per eBay T&Cs
    if ( in_array(fuEbayDisplayFields::EbayLogo, $displayFields) )
      $results .= "<h6 class=\"fu_ebay_listing_rightnowonebay\">" . fuEbayUtils::GetRightNowLogoHtml($this->Url) ."</h6>\n";
    
    // Not top title
    if ( in_array(fuEbayDisplayFields::Title, $displayFields) && ($this->Arrangement & fuEbayArrangement::TitleTop) == 0 )		
      $results .= "<h6 class=\"fu_ebay_title\">" . fuEbayUtils::GetEbayLink($this->Url, $this->Title, $this->ItemId) ."</h6>\n";

    // Condition
    if ( in_array(fuEbayDisplayFields::Condition, $displayFields) && $this->Condition != null)
      $results .= "<div class=\"fu_ebay_condition\">" . __("Condition", "fast-ebay-listings") . ": " . $this->Condition . "</div>\n";
          
    // Price
    if ( in_array(fuEbayDisplayFields::Price, $displayFields) )
    {
      $priceStatus = "fu_ebay_priceactive";
      if ( !$this->Active ) 
      {
        $priceStatus = $this->Sold ? "fu_ebay_pricesold" : "fu_ebay_priceunsold";
      }			
      
      $pricePriority = "";
      $priorityText = get_option('fubaby_ebayPriorityListingText', __("Great Deal!", "fast-ebay-listings"));
      if ( $this->priorityListing && !empty($priorityText) )
      {
        $pricePriority = "<span class=\"fu_ebay_prioritylistingtext\">{$priorityText}</span> ";
      }

      $results .= "<div class=\"{$priceStatus}\">{$pricePriority}{$this->Currency}{$this->PriceConv}</div>\n";

      if ( $this->Sold )
        $results .= "&nbsp;<div class=\"fu_ebay_soldtext\">" . __("Sold", "fast-ebay-listings") . "</div>\n";

      // Fixed Sale/Shop BIN images.
      if ( $this->ListingType == "FixedPrice" || $this->ListingType == "StoreInventory" )
      {
        $results .= $this->BINBestOffer ? fuEbayUtils::GetBINBestOfferLogoHtml() : fuEbayUtils::GetBINLogoHtml();
      }
      
      // Fixed Sale/Shop BIN images.
      if ( $this->ListingType == "Classified" )
      {
        $results .= "&nbsp;<div class=\"fu_ebay_classifiedtext\">" . __("Classified&nbsp;Ad", "fast-ebay-listings") . "</div>\n";
      }
      
      // Bids
      if ( $this->ListingType == "Auction" || $this->ListingType == "AuctionWithBIN" )
        $results .= "&nbsp;<div class=\"fu_ebay_bids\">(" . $this->AuctionBids . " " . _n("bid", "bids", $this->AuctionBids, "fast-ebay-listings") . ")</div>\n";
                    
      // Auctions with an additional BIN price.
      if ( $this->ListingType == "AuctionWithBIN" )
      {
        $results .= "\n<div class=\"fu_ebay_pricebin\">";
        $results .= "{$this->Currency}{$this->PriceBINConv}";
        $results .= "</div>\n";
        $results .= $this->BINBestOffer ? fuEbayUtils::GetBINBestOfferLogoHtml() : fuEbayUtils::GetBINLogoHtml();
      }
    }

    // Auction End Time.
    if ( in_array(fuEbayDisplayFields::EndTime, $displayFields) && $this->EndTime != null)
      $results .= "<div class=\"fu_ebay_endtime\">" . $this->GetEndTime() . "</div>\n";

    // StoreName
    if ( in_array(fuEbayDisplayFields::Store, $displayFields) && !empty($this->StoreName) )
     $results .= "<div class=\"fu_ebay_storename\">" . __("Shop", "fast-ebay-listings") . ": " . $this->StoreName . "</div>\n";    

    // SellerName
    if ( in_array(fuEbayDisplayFields::Seller, $displayFields) && !empty($this->SellerName) )
      $results .= "<div class=\"fu_ebay_storename\">" . __("Seller", "fast-ebay-listings") . ": " . $this->SellerName . "</div>\n";    
  
    // Seller feedback.
    if ( in_array(fuEbayDisplayFields::Feedback, $displayFields) && $this->Feedback != null )
      $results .= "<div class=\"fu_ebay_feedback\">" . __("Seller Feedback", "fast-ebay-listings") . ": " . intval($this->Feedback) . " (" . $this->FeedbackPercent . "%)</div>\n";    
    
    // Location
    if ( in_array(fuEbayDisplayFields::Location, $displayFields) && !empty($this->Location) )
      $results .= "<div class=\"fu_ebay_location\">" . __("Location", "fast-ebay-listings") . ": " . $this->Location . "</div>\n";

    return $results;
  }

  // Class Properties.
  public $Arrangement = 0;
    
  public $ItemId;			//!< Listing ProductID
  public $ListingType; //!< Listing type.
  public $Title;     //!< Listing title
  public $ShortDescription; //!< Listing short description.
  public $Url;       //!< Listing URL
  public $Active;    //!< Listing active or completed.
  public $PicHuge;   //!< Large Picture (>800px)
  public $PicLarge;  //!< Large Picture (>400px)
  public $GalleryLarge;  //!< Large gallery picture (140px)
  public $GalleryMedium;  //!< Medium gallery picture (96px)
  public $GallerySmall;  //!< Small gallery picture (80px)
  
  public $StoreName;    //!< Name of eBay store with listing.
  public $SellerName;   //!< Name of eBay seller with listing.
  
  public $Currency;      //!< Currency of listing.
  public $Price;         //!< Price of listing in above currency
  public $PriceConv;     //!< Price of listing converted to global currency.
  public $PriceBIN;      //!< Buy It Now price of listing.
  public $PriceBINConv;  //!< Buy It Now price converted to global currency.
  public $Sold;          //!< For completed listings, whether item sold or not.
  
  public $Auction;
  public $AuctionBids;
  public $BIN;
  public $BINBestOffer;
  
  public $EndTime;       //!< Listing end time.
  public $Location;      //!< Sellers location.
  public $Feedback;          //!< Sellers feedback score.
  public $FeedbackPercent;   //!< Percentage of positive feedback.

  public $Condition;     //!< Item condition

  
  public $priorityListing = false;
}
