(function() {
	tinymce.PluginManager.add('ebay_search', function( editor, url ) {
		var sh_tag = 'ebay_search';
		var stubId = "ebay_search";

		//helper functions 
		function getAttr(s, n) {
			r = new RegExp(n + '=\"([^\"]*)\"', 'g').exec(s);
			if (!r) r = new RegExp(n + '=(.+?)([\\s$])', 'g').exec(s);
			return r ?  window.decodeURIComponent(r[1]) : '';
		};

		function jsonEnc(str) {
			var out = JSON.stringify(str);
			return out.replace(/^"(.+(?="$))"$/, '$1');
		}

		function html(dat, con) {
			var placeholder = url + '/images/ebaysearchpanel.jpg';
			data = window.encodeURIComponent( dat );
			content = window.encodeURIComponent( con );
			var html = '<img src="' + placeholder + '" class="mceItem wp-' + sh_tag + '" ';
      html += 'title="' + editor.getLang("extrastrings.dblClicktoEdit") + '" ';
      html += 'data-sh-attr="' + data + '" data-sh-content="'+ con+'" data-mce-resize="false" data-mce-placeholder="1" />';
			return html;
		}

		function replaceShortcodes( content ) {
			return content.replace( /\[(fu_ebay_search|ebay_search)([^\]]*)\]([^\]]*)\[\/(fu_ebay_search|ebay_search)\]/g, function( all,tag,attr,con) {
        var placeholder = url + '/images/ebaysearchpanel.jpg';
        attr = window.encodeURIComponent( attr );
        content = window.encodeURIComponent( con );
        var html = '<img src="' + placeholder + '" class="mceItem wp-' + sh_tag + '" ';
        html += 'title="' + editor.getLang("extrastrings.dblClicktoEdit") + '" ';
        html += 'data-sh-attr="' + attr + '" data-sh-content="'+ con+'" data-mce-resize="false" data-mce-placeholder="1" />';
        return html;
      });
		}

		function restoreShortcodes( content ) {
			return content.replace( /(?:<p(?: [^>]+)?>)*(<img [^>]+>)(?:<\/p>)*/g, function( match, image ) {
				if (!getAttr( image, 'class' ).includes('wp-' + sh_tag)) return match;
				var data = getAttr( image, 'data-sh-attr' );
				var con = getAttr( image, 'data-sh-content' );

				if ( data ) {
					return '<p>[' + sh_tag + data + ']' + con + '[/'+sh_tag+']</p>';
				}
				return match;
			});
		}

    function addHtmlSpecialChars(str) {
      return str.replace(/&/g, "&amp;").replace(/>/g, "&gt;").replace(/</g, "&lt;").replace(/"/g, "&quot;");
    }

    function removeHtmlSpecialChars(str) {
      return str.replace(/&amp;/g, "&").replace(/&gt;/g, ">").replace(/&lt;/g, "<&lt;>").replace(/&quot;/g, "\"");
    }

    function validateForm(data) {
      var gotQuery = typeof data.query != 'undefined' && data.query.length > 0;
      var gotCategory = (typeof data.category != 'undefined' && data.category.length > 0) || fuScriptShortcode.ebayDefCategory.length > 0;

      if (!gotQuery && !gotCategory)
        return editor.getLang('extrastrings.invalidQueryCategoryNotBlank');

      if (typeof data.minprice != 'undefined' && data.minprice.length && typeof data.maxprice != 'undefined' && data.maxprice.length) {
        const minPrice = Number(data.minprice);
        const maxPrice = Number(data.maxprice);

        if (minPrice > maxPrice)
          return editor.getLang('extrastrings.invalidMinPriceGreaterThanMax');
      }

      return "";
    }

		//add popup
		editor.addCommand('ebay_search_popup', function(ui, v) {
			//setup defaults
			var content = v.content ? v.content : '';
			var query = v.query ? removeHtmlSpecialChars(v.query) : '';
			var category = v.category ? removeHtmlSpecialChars(v.category) : '';
			var seller = v.seller ? removeHtmlSpecialChars(v.seller) : '';
			var sellertype = v.sellertype ? v.sellertype : '';
			var buyingoptions = (v.buyingoptions ? v.buyingoptions : 'FIXED_PRICE|AUCTION|BEST_OFFER').split("|");
			var minprice = v.minprice ? v.minprice : '';
			var maxprice = v.maxprice ? v.maxprice : '';
			var sort = v.sort ? v.sort : '';
			var rows = v.rows ? v.rows : '';
			var columns = v.columns ? v.columns : '';
			var slideshow = v.slideshow ? v.slideshow : '';
			var slides = v.slides ? v.slides : '';
			var picwidth = v.picwidth ? v.picwidth : '';
			var customid = v.customid ? v.customid : '';
			
			editor.windowManager.open( {
				title: editor.getLang('extrastrings.felSearch'),
        //bodyType: 'tabpanel',
				body: [		 
          {
            //title: 'TabPanels',
            type: 'tabpanel',
            items: [
              // Search Criteria Tab Panel
              {
                title: editor.getLang('extrastrings.searchTabTitle'),
                type: 'form',
                items: [
                  {
                    type: 'textbox',
                    name: 'content',
                    label: editor.getLang('extrastrings.resultsTitleLabel'),
                    value: content,
                    tooltip: editor.getLang('extrastrings.resultsTitleToolTip'),
                  },				       
                  {
                    type: 'textbox',
                    name: 'query',
                    label: editor.getLang('extrastrings.queryLabel'),
                    value: query,
                    tooltip: editor.getLang('extrastrings.queryToolTip'),
                    minWidth: 300,
                  },
                  {
                    type: 'textbox',
                    name: 'category',
                    classes: 'fu_ebay_category_input',
                    label: editor.getLang('extrastrings.categoryLabel'),
                    value: category,
                    placeholder: fuScriptShortcode.ebayDefCategory,
                    tooltip: editor.getLang('extrastrings.blankUseDefaults')
                  },
                  {
                    type: 'textbox',
                    name: 'seller',
                    label: editor.getLang('extrastrings.sellerLabel'),
                    value: seller,
                    placeholder: fuScriptShortcode.ebayDefSeller,
                    tooltip: editor.getLang('extrastrings.sellerToolTip')
                  },
                  {
                    type: 'listbox',
                    name: 'sellertype',
                    label: editor.getLang('extrastrings.sellerTypeLabel'),
                    value: sellertype,
                    'values': [						           
                      {text:  editor.getLang('extrastrings.useSettingsDefault'), value: ''},
                      {text:  editor.getLang('extrastrings.sellerAny'), value: 'BUSINESS|INDIVIDUAL'},
                      {text:  editor.getLang('extrastrings.sellerBusiness'), value: 'BUSINESS'},
                      {text:  editor.getLang('extrastrings.sellerIndividual'), value: 'INDIVIDUAL'},
    
                    ],
                    tooltip: editor.getLang('extrastrings.sellerTypeToolTip')
                  },
                  {
                    layout: 'grid',
                    name: 'align',
                    label: editor.getLang('extrastrings.buyingOptionsLabel'),
                    type: 'form',
                    columns: '3',
                    spacingH: 10,
                    spacingV: 0,
                    items: [
                      {
                        type: 'checkbox',
                        name: 'buyingOptionFixedPrice',
                        checked: buyingoptions.includes("FIXED_PRICE"),
                        label: editor.getLang('extrastrings.buyingOptionsFixedPrice'),
                        maxWidth: 100,
                        maxLength: 10,
                      },						
                      {
                        type: 'checkbox',
                        name: 'buyingOptionAuction',
                        checked: buyingoptions.includes("AUCTION"),
                        label: editor.getLang('extrastrings.buyingOptionsAuction'),
                        maxWidth: 100,
                        maxLength: 10,
                      },	
                      {
                        type: 'checkbox',
                        name: 'buyingOptionBestOffer',
                        checked: buyingoptions.includes("BEST_OFFER"),
                        label: editor.getLang('extrastrings.buyingOptionsBestOffer'),
                        maxWidth: 100,
                        maxLength: 10,
                      },	
                    ]
                  },
                  {
                    layout: 'grid',
                    name: 'align',
                    label: editor.getLang('extrastrings.minMaxPriceLabel'),
                    type: 'form',
                    columns: '2',
                    spacingH: 10,
                    spacingV: 0,
                    items: [
                      {
                        type: 'textbox',
                        subtype: 'number',
                        name: 'minprice',
                        value: minprice,
                        tooltip: editor.getLang('extrastrings.minMaxPriceToolTip'),
                        maxWidth: 100,
                        maxLength: 10,
                      },						
                      {
                        type: 'textbox',
                        subtype: 'number',
                        name: 'maxprice',
                        value: maxprice,
                        tooltip: editor.getLang('extrastrings.minMaxPriceToolTip'),
                        maxWidth: 100,
                        maxLength: 10,
                      },	
                    ]
                  },
                ]
              },
              // Presentation Tab Panel
              {
                title: editor.getLang('extrastrings.presentationTabTitle'),
                type: 'form',
                items: [
                  {
                    type: 'listbox',
                    name: 'sort',
                    label: editor.getLang('extrastrings.sortingLabel'),
                    value: sort,
                    'values': [						           
                      {text:  editor.getLang('extrastrings.useSettingsDefault'), value: ''},
                      {text:  editor.getLang('extrastrings.sortingBestMatch'), value: 'BestMatch'},
                      {text:  editor.getLang('extrastrings.sortingCurrentPriceHighest'), value: 'CurrentPriceHighest'},
                      {text:  editor.getLang('extrastrings.sortingDistanceNearest'), value: 'DistanceNearest'},
                      {text:  editor.getLang('extrastrings.sortingEndTimeSoonest'), value: 'EndTimeSoonest'},
                      {text:  editor.getLang('extrastrings.sortingPricePlusShippingHighest'), value: 'PricePlusShippingHighest'},
                      {text:  editor.getLang('extrastrings.sortingPricePlusShippingLowest'), value: 'PricePlusShippingLowest'},
                      {text:  editor.getLang('extrastrings.sortingStartTimeNewest'), value: 'StartTimeNewest'}
                    ],
                    tooltip: editor.getLang('extrastrings.sortingToolTip')
                  },              
                  {
                    type: 'textbox',
                    subtype: 'number',
                    name: 'picwidth',
                    label: editor.getLang('extrastrings.picWidthLabel'),
                    value: picwidth,
                    placeholder: fuScriptShortcode.ebayPicWidthList,
                    tooltip: editor.getLang('extrastrings.blankUseDefaults'),
                    maxWidth: 100,
                    maxLength: 4,
                  },	
                  {
                    layout: 'grid',
                    name: 'align',
                    label: editor.getLang('extrastrings.resultsColRowsLabel'),
                    type: 'form',
                    columns: '2',
                    spacingH: 10,
                    spacingV: 0,
                    items: [
                      {
                        type: 'textbox',
                        subtype: 'number',
                        name: 'columns',
                        value: columns,
                        placeholder: fuScriptShortcode.ebayDefColumns,
                        tooltip: editor.getLang('extrastrings.blankUseDefaults'),
                        maxWidth: 100,
                        maxLength: 2,
                      },	
                      {
                        type: 'textbox',
                        subtype: 'number',
                        name: 'rows',
                        value: rows,
                        placeholder: fuScriptShortcode.ebayDefRows,
                        tooltip: editor.getLang('extrastrings.blankUseDefaults'),
                        maxWidth: 100,
                        maxLength: 2,
                      },	
                    ]
                  },							
                  {
                    layout: 'grid',
                    name: 'align',
                    label: editor.getLang('extrastrings.slideShowLabel'),
                    type: 'form',
                    columns: '2',
                    spacingH: 10,
                    spacingV: 0,
                    items: [
                      {
                        type: 'listbox',
                        name: 'slideshow',
                        value: slideshow,
                        'values': [						           
                              {text: editor.getLang('extrastrings.useSettingsDefault'), value: ''},
                              {text: editor.getLang('extrastrings.slideShowNone'), value: 'None'},
                              {text: editor.getLang('extrastrings.slideShowManual'), value: 'Manual'},
                              {text: editor.getLang('extrastrings.slideShowAuto'), value: 'Auto'},
                            ],
                      },						
                      {
                        type: 'textbox',
                        subtype: 'number',
                        name: 'slides',
                        value: slides,
                        placeholder: fuScriptShortcode.ebayDefNumSlides,
                        tooltip: editor.getLang('extrastrings.blankUseDefaults'),
                        maxWidth: 50,
                        maxLength: 2,
                      },	
                    ]
                  },
                ]
              },
              // EPN Tab Panel
              {
                title: editor.getLang('extrastrings.epnTabTitle'),
                type: 'form',
                items: [
                  {
                    type: 'textbox',
                    name: 'customid',
                    label: editor.getLang('extrastrings.customIdLabel'),
                    value: customid,
                    placeholder: fuScriptShortcode.ebayDefCustomID,
                    tooltip: editor.getLang('extrastrings.customIdToolTip'),
                    maxWidth: 300,
                  },	
    
                  
                ]
              }
            ]
          }
        ],
        onsubmit: function( e ) {

          //check if code valid
          var validationError = validateForm(e.data);    
          if (validationError.length > 0) {
            //if code invalid, display error message and keep text editor window open
            tinyMCE.activeEditor.windowManager.alert(validationError);
            return false;
          }

          var shortcode_str = '[' + sh_tag;
          // check for query
          if (typeof e.data.query != 'undefined' && e.data.query.length)
            shortcode_str += ' query="' + addHtmlSpecialChars(e.data.query) + '"';
          // check for category
          if (typeof e.data.category != 'undefined' && e.data.category.length)
            shortcode_str += ' category="' + addHtmlSpecialChars(e.data.category) + '"';
          // check for seller
          if (typeof e.data.seller != 'undefined' && e.data.seller.length)
            shortcode_str += ' seller="' + addHtmlSpecialChars(e.data.seller) + '"';
          if (typeof e.data.sellertype != 'undefined' && e.data.sellertype.length)
            shortcode_str += ' sellertype="' + e.data.sellertype + '"';
          // Buying options
          buyingOptions = [];
          if (typeof e.data.buyingOptionFixedPrice != 'undefined' && e.data.buyingOptionFixedPrice)
            buyingOptions.push("FIXED_PRICE");
          if (typeof e.data.buyingOptionAuction != 'undefined' && e.data.buyingOptionAuction)
            buyingOptions.push("AUCTION");
          if (typeof e.data.buyingOptionBestOffer != 'undefined' && e.data.buyingOptionBestOffer)
            buyingOptions.push("BEST_OFFER");
          shortcode_str += ' buyingoptions="' + buyingOptions.join("|") + '"';
          // check for min/max price
          if (typeof e.data.minprice != 'undefined' && e.data.minprice.length)
            shortcode_str += ' minprice="' + e.data.minprice + '"';
          if (typeof e.data.maxprice != 'undefined' && e.data.maxprice.length)
            shortcode_str += ' maxprice="' + e.data.maxprice + '"';
          // add sort
          if (typeof e.data.sort != 'undefined' && e.data.sort.length)
            shortcode_str += ' sort="'+e.data.sort+'"';
          // check for rows/columns
          if (typeof e.data.rows != 'undefined' && e.data.rows.length)
            shortcode_str += ' rows="' + e.data.rows + '"';
          if (typeof e.data.columns != 'undefined' && e.data.columns.length)
            shortcode_str += ' columns="' + e.data.columns + '"';
          // check for slides
          if (typeof e.data.slideshow != 'undefined' && e.data.slideshow.length)
            shortcode_str += ' slideshow="'+e.data.slideshow+'"';
          if (typeof e.data.slides != 'undefined' && e.data.slides.length)
            shortcode_str += ' slides="' + e.data.slides + '"';
          // check for picwidth
          if (typeof e.data.picwidth != 'undefined' && e.data.picwidth.length)
            shortcode_str += ' picwidth="' + e.data.picwidth + '"';
          // check for customid
          if (typeof e.data.customid != 'undefined' && e.data.customid.length)
            shortcode_str += ' customid="' + e.data.customid + '"';

          //add panel content
          shortcode_str += ']' + e.data.content + '[/' + sh_tag + ']';
          //insert shortcode to tinymce
          editor.insertContent( shortcode_str);
        }
      });
    });

		//replace from shortcode to an image placeholder
		editor.on('BeforeSetcontent', function(event){ 
			event.content = replaceShortcodes( event.content );
		});

		//replace from image placeholder to shortcode
		editor.on('GetContent', function(event){
			event.content = restoreShortcodes(event.content);
		});

		//open popup on placeholder double click
		editor.on('DblClick',function(e) {
			var cls  = e.target.className.indexOf('wp-' + sh_tag);
			if ( e.target.nodeName == 'IMG' && e.target.className.indexOf('wp-' + sh_tag) > -1 ) {
				var data = e.target.attributes['data-sh-attr'].value;
				var content = e.target.attributes['data-sh-content'].value;
				data = window.decodeURIComponent(data);
				content = window.decodeURIComponent(content);

				editor.execCommand('ebay_search_popup','',{
					query : getAttr(data,'query'),
					category : getAttr(data,'category'),
					seller : getAttr(data,'seller'),
					sellertype : getAttr(data,'sellertype'),
					buyingoptions : getAttr(data,'buyingoptions'),
					minprice : getAttr(data,'minprice'),
					maxprice : getAttr(data,'maxprice'),
					sort   : getAttr(data,'sort'),
					rows   : getAttr(data,'rows'),
					columns   : getAttr(data,'columns'),
					slideshow   : getAttr(data,'slideshow'),
					slides   : getAttr(data,'slides'),
					picwidth : getAttr(data,'picwidth'),
					customid : getAttr(data,'customid'),
					content: content
				});
			}
		});
	});
})();