<?php

//////////////////////////////////////////////////////////////////////////
//
// Trait to handle presentation of apicall results
//
//////////////////////////////////////////////////////////////////////////

$fuEbayTableSlideId = 0;

trait fuEbayTable
{
  private $limit = -1;
  public $columns = 1;
  public $rows = 1;
  
  private $slideLimit = -1;
  public $slideShow = fuEbaySlideShowStyle::None;
  public $slides;
  
  private $nItems;
  private $nSlides;
  
  public function setTableSize($columns, $rows)
  {
    $this->columns = intval($columns);
    if ($this->columns < 1) $this->columns = get_option('fubaby_ebayDefColumns');
    if ($this->columns < 1) $this->columns = 1;
    if ($this->columns > FUBABY_EBAY_MAXCOLUMNS) $this->columns = FUBABY_EBAY_MAXCOLUMNS;
    
    $this->rows = intval($rows);
    if ($this->rows < 1) $this->rows = get_option('fubaby_ebayDefRows');
    if ($this->rows < 1) $this->rows = 1;
    
    // Calculate a slideLimit value from 
    if ($this->rows > 0) $this->slideLimit = $this->columns * $this->rows;
    else $this->slideLimit = $this->columns;  
  }
  
  public function setSlideShow($slideShow, $slides = -1)
  {
    $this->slideShow = $slideShow;
    $this->slides = intval($slides);
    if ($this->slides <= 0) $this->slides = get_option('fubaby_ebayDefNumSlides');
    
    if ($this->slideShow == "1" || 
        stristr($this->slideShow, "true") !== false ||
        stristr($this->slideShow, "default") !== false)
      $this->slideShow = get_option('fubaby_ebayDefSlideshowStyle');

    // If no slideShow, no point having limit beyond what we'll present 
    switch ($this->slideShow)
    {
      case -1:
      case fuEbaySlideShowStyle::None:
      case false:
        $this->slides = 1;
        if ($this->limit > $this->columns * $this->rows)
          $this->limit = $this->columns * $this->rows;
        break;
      default:
        if ($this->slides > 0)
          $this->limit = $this->columns * $this->rows * $this->slides;
    }
  }
  
  public function validate()
  {
    if ($this->columns < 1) $this->columns = get_option('fubaby_ebayDefColumns');
    if ($this->columns < 1) $this->columns = 1;    
    if ($this->rows < 1) $this->rows = get_option('fubaby_ebayDefRows');
    if ($this->rows < 1) $this->rows = 1;
    
    if ($this->limit < 1)
      $this->limit = $this->columns * $this->rows;
    
    // Ensure we have a valid slide limit, should be multiple of columns.
    $this->slideLimit = intval($this->slideLimit);
    if ($this->slideLimit < 1) $this->slideLimit = $this->columns;
    if (($this->slideLimit % $this->columns) > 0) $this->slideLimit += $this->columns - ($this->slideLimit % $this->columns);
    if ($this->slideLimit == $this->limit) $this->slideShow = fuEbaySlideShowStyle::None;
  }
  
  public function genTableStart(string $searchUrl)
  {
    global $ebay_colour_class;
    $this->nItems = 0;
    $this->nSlides = 0;
    
    $colourStyle = get_option('fubaby_ebayColourStyle', fuEbayColourStyle::Default);

    // Start table.
    $this->result .= "<div class=\"fu_ebay_results_container {$ebay_colour_class[$colourStyle]}\">\r\n";
    $this->result .= "<h5 class=\"fu_ebay_results_title\">\r\n";
    // Display of the 'Right now on eBay' logo is mandatory as per eBay T&Cs
    $this->result .= fuEbayUtils::GetRightNowLogoHtml($searchUrl);
    $this->result .= "&nbsp;";
    if ( $this->title != "" )
    {
      $this->result .= fuEbayUtils::GetEbayLink($searchUrl, $this->title, '');
    }
    $this->result .= "</h5>\r\n"; // fu_ebay_results_title
  }

  public function genTableItem(string $itemHtml)
  {
    global $fuEbayTableSlideId;
    $slideShowClasses = $this->slideShow != fuEbaySlideShowStyle::None ? " fu_ebay_slide_{$fuEbayTableSlideId} fu_ebay_slidefade" : "";
    
    if ($this->slideShow != fuEbaySlideShowStyle::None)
    {
      $itemHtml = str_replace("class=\"fu_ebay_title\"", "class=\"fu_ebay_title fu_ebay_maxtwolines\"", $itemHtml);
    }
    
    if (($this->nItems % $this->slideLimit) == 0 )
    {
      $this->result .= "<div class=\"fu_ebay_results{$slideShowClasses}\">\r\n";
    }
    
    if (($this->nItems % $this->columns) == 0)
    {
      $this->result .= "<div class=\"fu_ebay_results_row\">\r\n";
    }
  
    $this->result .= "<div class=\"fu_ebay_results_cellcommon fu_ebay_results_cell{$this->columns}\" style=\"\" >\r\n";
    $this->result .= $itemHtml;
    $this->result .= "\r\n</div>\r\n";
  
    ++$this->nItems;
  
    if (($this->nItems % $this->columns) == 0)
    {
      $this->result .= "</div>\r\n"; // fu_ebay_results_row
    }

    if (($this->nItems % $this->slideLimit) == 0)
    {
      $this->result .= "</div> <!-- .fu_ebay_results -->\r\n"; // fu_ebay_results
      ++$this->nSlides;
    }
  }
  
  public function genTableEnd()
  {
    global $fuEbayTableSlideId;
    $closeNeeded = false;

    // Close last row if needed.
    if (($this->nItems % $this->columns) != 0)
    {
      $this->result .= "</div>\r\n"; // fu_ebay_results_row
      $closeNeeded = true;
    }

    // Close last slide if needed.
    if (($this->nItems % ($this->columns * $this->rows)) != 0)
    {
      $closeNeeded = true;
    }

    if ($closeNeeded)
      ++$this->nSlides;

    if (($this->nItems % $this->slideLimit) != 0)
    {
      $this->result .= "</div> <!-- .fu_ebay_results -->\r\n"; // fu_ebay_results
    }

    $this->genSlideshowDots(); 

    $this->result .= fuEbayUtils::GetFELLinkHtml();
    $this->result .= "</div>\r\n"; // fu_ebay_results_container
    
    ++$fuEbayTableSlideId;
  }  
  
  public function limitHit(): int
  {
    return $this->nItems >= $this->limit;
  }
  
 
  private function genSlideshowDots()
  {
    global $fuEbayTableSlideId;
    // Slideshow dots along bottom
    if ($this->slideShow != fuEbaySlideShowStyle::None && $this->nSlides > 1)
    {
      $this->result .= "<script type=\"text/javascript\">fu_ebay_slideIndex[$fuEbayTableSlideId] = 0;</script>";
      $this->result .= "<div style=\"text-align:center\">";
      $this->result .= "<span class=\"fu_ebay_slideprev\" onclick=\"plusSlides(-1, $fuEbayTableSlideId)\">&#10094;</span>";
      for ($i=0; $i<$this->nSlides; ++$i)
      {
        $this->result .= "<span class=\"fu_ebay_slidedot fu_ebay_slidedot_$fuEbayTableSlideId\" onclick=\"currentSlide($i, $fuEbayTableSlideId)\"></span>";
      }
      $this->result .= "<span class=\"fu_ebay_slidenext\" onclick=\"plusSlides(1, $fuEbayTableSlideId)\">&#10095;</span>";
      
      $this->result .= "</div>";
      $this->result .= "<script type=\"text/javascript\">showSlide(0, $fuEbayTableSlideId);</script>";
      
      if ($this->slideShow == fuEbaySlideShowStyle::Auto)
        $this->result .= "<script type=\"text/javascript\">autoShowSlide($fuEbayTableSlideId);</script>";
    }
  }  
}


class fuEbayUtils
{
  public static function GetEbayLink(string $url, string $title, string $itemId, string $content = ""): string
  {
    $newWindow = get_option('fubaby_ebayNewWindow', 1) == 1;
  	$gaTrackingOn = get_option('fubaby_ebayGATracking', 0) == 1;

  	if ( $content == '' ) $content = htmlentities($title, ENT_QUOTES | ENT_SUBSTITUTE | ENT_HTML401, null, false);
    $buyurl = htmlspecialchars($url, ENT_QUOTES | ENT_SUBSTITUTE | ENT_HTML401, null, false);
    $titleAttr = htmlentities($title, ENT_QUOTES | ENT_SUBSTITUTE | ENT_HTML401, null, false);
  	
  	// Build up anchor element.
  	$result = "<a href=\"{$buyurl}\"";
  	$result .= " title=\"{$titleAttr}\"";
  	if ( $gaTrackingOn != 0 )
  		$result .= " onClick=\"fu_ebay_recordOutboundLink(this, $newWindow, 'Outbound eBay Links', '$itemId', '$titleAttr');return false;\"";

    $target = $newWindow ? "target=\"_blank\"" : "";
    $result .= " rel=\"nofollow\" {$target}>{$content}</a>";
  	return $result;	
  }

  // Must point to eBay per guidelines. See: https://developer.ebay.com/promote/logos#2
  public static function GetRightNowLogoHtml($url = "http://www.ebay.com"): string
  {
    global $ebay_globalid_logos;
    $globalid = get_option('fubaby_ebayGlobalID');
    $logoUrl = plugins_url(basename(__DIR__) .  $ebay_globalid_logos[$globalid]);
    $url = htmlspecialchars($url, ENT_QUOTES | ENT_SUBSTITUTE | ENT_HTML401, null, false);

    $target = get_option('fubaby_ebayNewWindow', 1) == 1 ? "target=\"_blank\"" : "";
    $result = "<a href=\"{$url}\" rel=\"nofollow\" {$target}>";
    $result .= "<img src=\"{$logoUrl}\" style=\"border: 0;\" width=\"108\" height=\"45\" alt=\"" . __("Right Now on eBay", "fast-ebay-listings") . "\"/>";
    $result .= "</a>";
    return $result;
  }
  
  public static function GetBINLogoHtml(): string
  {
    switch (substr(get_locale(), 0, 2))
    {
      case 'nl': case 'fr': case 'de': case 'it': case 'es':
        return "<div class=\"fu_ebay_buyingformat\">" . __("Buy it Now", "fast-ebay-listings") . "</div>";
      default:
        $logoUrl = plugins_url(basename(__DIR__) .  FUBABY_EBAY_BINLOGOIMG);
        return " <img src=\"{$logoUrl}\" class=\"fu_ebay_binlogo\" width=\"54\" height=\"15\" alt=\"" . __("Buy it Now", "fast-ebay-listings") . "\"/>";   
    }
  }
  
  public static function GetBINBestOfferLogoHtml(): string
  {
    $logoUrl = plugins_url(basename(__DIR__) .  FUBABY_EBAY_BINBOLOGOIMG);
    return " <img src=\"{$logoUrl}\" class=\"fu_ebay_binlogo\" width=\"70\" height=\"20\" alt=\"" . __("Buy it Now or Best Offer", "fast-ebay-listings") . "\"/>";   
  }
  
  public static function GetSecureUrl(string $url): string
  {
    if (is_ssl())
      return str_replace("http://", "https://", $url);
    else 
      return $url;
  }
  
  public static function GetFELLinkHtml(): string
  {
    if (get_option('fubaby_ebayDisplayFELLink', '0') != '1')
      return "";

    $result = "<div class=\"fu_ebay_fel_link\">";
    $result .= __("Powered by ", "fast-ebay-listings");
    $result .= "<a href=\"" . FUBABY_EBAY_PLUGIN_WEBSITE . "\" target=\"_blank\">";
    $result .= "WordPress eBay Plugin - " . FUBABY_EBAY_PLUGIN_TITLE;
    $result .= "</a></div>";
    return $result;
  }  
    
}
