<?php

add_filter( 'mce_external_languages', 'fu_ebay_add_tinymce_lang', 10, 1 );

function fu_ebay_add_tinymce_lang( $arr )
{
    $arr[] = WP_PLUGIN_DIR . '/' . basename(__DIR__) . '/shortcode-lang-file.php';
    return $arr;
}

//////////////////////////////////////////////////////////////////////////
//
// Handle a search of items
//
//////////////////////////////////////////////////////////////////////////
abstract class fuEbayShortcodeBase{
  /**
   * $shortcode_tag
   * holds the name of the shortcode tag
   * @var string
   */
  public $shortcode_tag;
  
  /**
   * $mce_plugin_url
   * holds the name mce plugin js
   * @var string
   */
  protected $mce_plugin_url;
  
  /**
   * __construct
   * class constructor will set the needed filter and action hooks
   *
   * @param array $args
   */
  function __construct($args = array()){
    //add shortcode
    add_shortcode( $this->shortcode_tag, array( $this, 'shortcode_handler' ) );
    add_shortcode( 'fu_' . $this->shortcode_tag, array( $this, 'shortcode_handler' ) );
    
    if ( is_admin() ){
      add_action('admin_head', array( $this, 'admin_head') );
    }
  }

  /**
   * shortcode_handler
   * @param  array  $atts shortcode attributes
   * @param  string $content shortcode content
   * @return string
   */
  abstract function shortcode_handler($atts , $content = null);

  /**
   * admin_head
   * calls your functions into the correct filters
   * @return void
   */
  function admin_head() {
    // check user permissions
    if ( !current_user_can( 'edit_posts' ) && !current_user_can( 'edit_pages' ) ) {
      return;
    }

    // check if WYSIWYG is enabled
    if ( 'true' == get_user_option( 'rich_editing' ) ) {
      add_filter( 'mce_external_plugins', array( $this ,'mce_external_plugins' ) );
      add_filter( 'mce_buttons', array($this, 'mce_buttons' ) );
    }
  }

  /**
   * mce_external_plugins
   * Adds our tinymce plugin
   * @param  array $plugin_array
   * @return array
   */
  function mce_external_plugins( $plugin_array ) {
    $plugin_array[$this->shortcode_tag] = plugins_url($this->mce_plugin_url, __FILE__ );
    return $plugin_array;
  }

  /**
   * mce_buttons
   * Adds our tinymce button
   * @param  array $buttons
   * @return array
   */
  function mce_buttons( $buttons ) {
    array_push( $buttons, $this->shortcode_tag );
    return $buttons;
  }
}//end class



//////////////////////////////////////////////////////////////////////////
//
// Setup ShortCode MCE ToolBar Buttons
//
//////////////////////////////////////////////////////////////////////////
class fuEbayShortcodeMCEToolbar
{

  /**
   * __construct
   * class constructor will set the needed filter and action hooks
   *
   * @param array $args
   */
  function __construct($args = array()){
    if ( is_admin() ){
      add_action('admin_head', array( $this, 'admin_head') );
      add_action( 'admin_enqueue_scripts', array($this , 'admin_enqueue_scripts' ) );
    }
  }

  /**
   * admin_head
   * calls your functions into the correct filters
   * @return void
   */
  function admin_head() {
    // check user permissions
    if ( !current_user_can( 'edit_posts' ) && !current_user_can( 'edit_pages' ) ) {
      return;
    }

    // check if WYSIWYG is enabled
    if ( 'true' == get_user_option( 'rich_editing' ) ) {
      add_filter( 'mce_external_plugins', array( $this ,'mce_external_plugins' ) );
      add_filter( 'mce_buttons', array($this, 'mce_buttons' ) );
    }
  }

  /**
   * mce_external_plugins
   * Adds our tinymce plugin
   * @param  array $plugin_array
   * @return array
   */
  function mce_external_plugins( $plugin_array ) {
    $plugin_array['fast_ebay_listings'] = plugins_url('mce/mce-button-core.js?v='.FUBABY_EBAY_PLUGIN_VER, __FILE__ );
    return $plugin_array;
  }

  /**
   * mce_buttons
   * Adds our tinymce button
   * @param  array $buttons
   * @return array
   */
  function mce_buttons( $buttons ) {
    array_push( $buttons, 'fast_ebay_listings' );
    return $buttons;
  }

  /**
   * admin_enqueue_scripts
   * Used to enqueue custom styles and extra JS params
   * @return void
   */
  function admin_enqueue_scripts(){
    wp_enqueue_style('fu_ebay_shortcode_styles', plugins_url('mce/mce-button-core.css', __FILE__ ), array(), FUBABY_EBAY_PLUGIN_VER);

    wp_register_script( 'fu_ebay_shortcode_script', '',);
    wp_enqueue_script('fu_ebay_shortcode_script');
    wp_localize_script('fu_ebay_shortcode_script', 'fuScriptShortcode', array(
      'pluginsUrl' => plugins_url('', __FILE__) . '/../',
      'ebayDefCategory' => get_option("fubaby_ebayDefCategory"),
      'ebayDefSeller' => get_option("fubaby_ebayDefSeller"),
      'ebayDefCustomID' => get_option("fubaby_ebayDefCustomID"),
      'ebayDefColumns' => get_option("fubaby_ebayDefColumns"),
      'ebayDefRows' => get_option("fubaby_ebayDefRows"),
      'ebayPicWidthItem' => get_option("fubaby_ebayPicWidthItem"),
      'ebayPicWidthList' => get_option("fubaby_ebayPicWidthList"),
      'ebayDefNumSlides' => get_option("fubaby_ebayDefNumSlides"),
    ));
  }  
}//end class

new fuEbayShortcodeMCEToolbar();