<?php
//////////////////////////////////////////////////////////////////////////
//
// Class with general utility funcs
//
//////////////////////////////////////////////////////////////////////////


////////////////////////////////////////////////////////////////////////////////////////////////////////

require_once __DIR__."/constants.php";


////////////////////////////////////////////////////////////////////////////////////////////////////////
// Add CSS styles to header.

function fu_ebay_addstyles() 
{
  // load up styles file to add inline
  $myStyleFile = WP_PLUGIN_DIR . '/' . basename(__DIR__) . '/styles.css';
  if ( file_exists($myStyleFile) ) 
  {
    $styleContents = file_get_contents($myStyleFile);

    // append any programatically derived styles
    $maxTitleLines = (int)get_option('fubaby_ebayTitleMaxLines', 0);
    if ($maxTitleLines > 0)
    $styleContents .= ".fu_ebay_title a {overflow:hidden;text-overflow:ellipsis;display:-webkit-box;-webkit-line-clamp:$maxTitleLines;line-clamp:$maxTitleLines; -webkit-box-orient:vertical;";

    wp_register_style('fu_ebay_style', '');
    wp_enqueue_style( 'fu_ebay_style', '', array(), FUBABY_EBAY_PLUGIN_VER);
    wp_add_inline_style('fu_ebay_style', $styleContents);
  }
}
add_action('wp_print_styles', 'fu_ebay_addstyles');

function fu_ebay_addadminstyles() 
{
  wp_enqueue_style('fu_ebay_style', plugins_url('styles.css', __FILE__ ), array(), FUBABY_EBAY_PLUGIN_VER);
  wp_enqueue_style('fu_ebay_adminstyle', plugins_url('admin_styles.css', __FILE__ ), array(), FUBABY_EBAY_PLUGIN_VER);
  wp_enqueue_style('fu_ebay_catstyle', plugins_url('/cats/cat_styles.css', __FILE__ ), array(), FUBABY_EBAY_PLUGIN_VER);

  // Needed for TinyMCE toolbar
  echo '<link rel="stylesheet" href="https://use.fontawesome.com/releases/v5.0.13/css/all.css" integrity="sha384-DNOHZ68U8hZfKXOrtjWvjxusGo9WQnrNx2sqG0tfsghAvtVlRW3tvkXWZh58N9jp" crossorigin="anonymous">';
}
add_action('admin_head', 'fu_ebay_addadminstyles');

////////////////////////////////////////////////////////////////////////////////////////////////////////
// Add JS scripts to header.

function fu_ebay_addscripts() 
{
  global $fu_ebay_bot_useragents;
  $myScriptFile = WP_PLUGIN_DIR . '/' . basename(__DIR__) . '/script.js';
  $myScriptFilePro = WP_PLUGIN_DIR . '/' . basename(__DIR__) . '/script_pro.js';
  if ( file_exists($myScriptFile) ) 
  {
    if (!wp_script_is('jquery', 'done'))
      wp_enqueue_script( 'jquery' );
 
    wp_add_inline_script( 'jquery-migrate', 'jQuery(document).ready(function(){});' );    
    $scriptContents = "/* FEL v" . FUBABY_EBAY_PLUGIN_VER . " */\n";
    $scriptContents .= "const fu_ebay_bot_useragents = [";
    foreach ($fu_ebay_bot_useragents as $fu_ebay_bot_useragent) $scriptContents .= "'{$fu_ebay_bot_useragent}',";
    $scriptContents .= "];\n";
    $scriptContents .= file_get_contents($myScriptFile);
    if ( file_exists($myScriptFilePro) ) 
     $scriptContents .= file_get_contents($myScriptFilePro);

    wp_register_script('fu_ebay_script', '', array('wp-i18n'));
    wp_enqueue_script('fu_ebay_script');	
    wp_add_inline_script('fu_ebay_script', $scriptContents, 'after');
  }
}
add_action('wp_enqueue_scripts', 'fu_ebay_addscripts');

function fu_ebay_addadminscripts() 
{
  global $ebay_globalid_hastaxonomy;
  if (!boolval(get_option('fubaby_ebayDisableCatChooser', 0)) &&  $ebay_globalid_hastaxonomy[get_option('fubaby_ebayGlobalID')])
  {
    wp_register_script('fu_ebay_cat_script', plugins_url( '/cats/cat_script.js', __FILE__ ),  array('jquery', 'wp-i18n'), FUBABY_EBAY_PLUGIN_VER, true);
    wp_enqueue_script('fu_ebay_cat_script');
    wp_set_script_translations('fu_ebay_cat_script', 'fast-ebay-listings');
  }

  wp_register_script('fu_ebay_admin_script', plugins_url( '/admin_script.js', __FILE__ ),  array('jquery', 'wp-i18n'), FUBABY_EBAY_PLUGIN_VER, true);
  wp_enqueue_script('fu_ebay_admin_script');
  wp_set_script_translations('fu_ebay_admin_script', 'fast-ebay-listings');

  wp_register_script('fu_ebay_block_script', '');    
  wp_enqueue_script('fu_ebay_block_script');
  wp_localize_script('fu_ebay_block_script', 'fuScriptBlock', array(
		'pluginsUrl' => plugins_url('', __FILE__) . '/',
    'ebayDefCategory' => get_option("fubaby_ebayDefCategory"),
    'ebayDefSeller' => get_option("fubaby_ebayDefSeller"),
    'ebayDefCustomID' => get_option("fubaby_ebayDefCustomID"),
    'ebayDefColumns' => get_option("fubaby_ebayDefColumns"),
    'ebayDefRows' => get_option("fubaby_ebayDefRows"),
    'ebayPicWidthList' => get_option("fubaby_ebayPicWidthList"),
    'ebayDefNumSlides' => get_option("fubaby_ebayDefNumSlides"),
	));
}
add_action('admin_enqueue_scripts', 'fu_ebay_addadminscripts');


////////////////////////////////////////////////////////////////////////////////////////////////////////
// Other utility methods


// https://www.php.net/manual/en/function.is-countable
if (! function_exists('is_countable')) {
  /**
    * @param mixed $value The value to check
    * @return bool
    */
  function is_countable($value): bool
  {
    return is_array($value) || (is_object($value) && $value instanceof Countable);
  }
}