<?php

require_once __DIR__."/apicall_browse_search.php";

////////////////////////////////////////////////////////////////////////////////////////////////////////
// Basic ebay search widget
class fuEbayWidgetSearch extends WP_Widget 
{
  protected $queryLabel = "Search Query";

	// constructor
	function __construct($name = '') 
	{
    if (empty($name)) $name = __('Fast eBay Fixed Search', 'fast-ebay-listings');
    parent::__construct(false, $name);
    $this->queryLabel =  __('Search Query', 'fast-ebay-listings');

    add_action( "admin_print_scripts-widgets.php", array( __CLASS__, 'registerValidationScript' ) );
	}

  static function registerValidationScript() {
    wp_register_script( 'fu_ebay_widget_script', plugins_url( '/widget_validation.js', __FILE__ ),  array( 'jquery', 'wp-i18n'), FUBABY_EBAY_PLUGIN_VER);
    wp_enqueue_script( 'fu_ebay_widget_script');
  }  

  function formIdNameAttrs($field)
  {
    echo "id=\"" . esc_attr( $this->get_field_id($field) ) . "\" name=\"" . esc_attr( $this->get_field_name($field) ) ."\"";
  }

	// widget form creation
	function form($instance) 
	{	
    global $ebay_sort_order;
    global $fu_ebay_slideshow_styles, $fu_seller_type_options, $fu_buying_options;
  
    $title = ! empty( $instance['title'] ) ? $instance['title'] : '';
    $content = ! empty( $instance['content'] ) ? $instance['content'] : '';
    $query = ! empty( $instance['query'] ) ? $instance['query'] : '';
    $category = ! empty( $instance['category'] ) ? $instance['category'] : '';
    $seller = ! empty( $instance['seller'] ) ? $instance['seller'] : '';
    $sellertype = ! empty( $instance['sellertype'] ) ? $instance['sellertype'] : '';
    $columns = ! empty( $instance['columns'] ) ? $instance['columns'] : 1;
    $rows = ! empty( $instance['rows'] ) ? $instance['rows'] : 1;
    $minprice = ! empty( $instance['minprice'] ) ? $instance['minprice'] : '';
    $maxprice = ! empty( $instance['maxprice'] ) ? $instance['maxprice'] : '';
    $sort  = ! empty( $instance['sort'] ) ? $instance['sort'] : '';
    $customid = ! empty( $instance['customid'] ) ? $instance['customid'] : '';
    $picwidth = ! empty( $instance['picwidth'] ) ? $instance['picwidth'] : '';
    $slideshow = ! empty( $instance['slideshow'] ) ? $instance['slideshow'] : 'None';    
    $slides = ! empty( $instance['slides'] ) ? $instance['slides'] : 3;
    ?>
  		<p>
  		<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_attr_e( 'Widget Title', 'fast-ebay-listings' ); ?></label> 
  		<input class="widefat" <?php $this->formIdNameAttrs('title'); ?> type="text" value="<?php echo esc_attr( $title ); ?>">
  		</p>
  		<p>
  		<label for="<?php echo esc_attr( $this->get_field_id( 'content' ) ); ?>"><?php esc_attr_e( 'Results Title', 'fast-ebay-listings' ); ?></label> 
  		<input class="widefat" <?php $this->formIdNameAttrs('content'); ?> type="text" value="<?php echo esc_attr( $content ); ?>">
  		</p>
  		<p>
  		<label for="<?php echo esc_attr( $this->get_field_id( 'query' ) ); ?>"><?php echo esc_attr( $this->queryLabel ); ?></label> 
  		<input class="widefat" <?php $this->formIdNameAttrs('query'); ?> type="text" value="<?php echo esc_attr($query); ?>">
  		</p>
  		<p>
  		<label for="<?php echo esc_attr( $this->get_field_id( 'category' ) ); ?>"><?php esc_attr_e( 'Category ID', 'fast-ebay-listings' ); ?></label> 
  		<input class="widefat fu_ebay_category_input" <?php $this->formIdNameAttrs('category'); ?> type="text" value="<?php echo esc_attr($category); ?>" placeholder="<?php echo esc_attr(get_option("fubaby_ebayDefCategory")); ?>">
  		</p>
  		<p>
  		<label for="<?php echo esc_attr( $this->get_field_id( 'seller' ) ); ?>"><?php esc_attr_e( 'Seller', 'fast-ebay-listings' ); ?></label> 
  		<input class="widefat" <?php $this->formIdNameAttrs('seller'); ?> type="text" value="<?php echo esc_attr($seller); ?>" placeholder="<?php echo esc_attr(get_option("fubaby_ebayDefSeller")); ?>">
  		</p>
  		<p>
  		<label for="<?php echo esc_attr( $this->get_field_id( 'sellertype' ) ); ?>"><?php esc_attr_e( 'Seller Type', 'fast-ebay-listings' ); ?></label> 
      <select class="widefat" <?php $this->formIdNameAttrs('sellertype'); ?> >
      <?php foreach ($fu_seller_type_options as $value => $desc) printf('<option value="%1$s" %2$s>%3$s</option>', esc_attr($value), $sort == $value ? 'selected' : '', $desc); ?>    
      </select>
  		</p>
  		<p>
  		<label for="<?php echo esc_attr( $this->get_field_id( 'buyingoptions' ) ); ?>"><?php esc_attr_e( 'Buying Options', 'fast-ebay-listings' ); ?></label>
      <div style="display: flex; flex-direction: row;">
      <?php foreach ($fu_buying_options as $value => $desc) : ?>
      <input style="margin: 5px;" type="checkbox" <?php $this->formIdNameAttrs('buyingoptions_' . $value); ?> 
      <?php if (isset($instance['buyingoptions_'.$value])) checked($instance['buyingoptions_'.$value], 'on'); ?>>
      <label style="width: 25%; margin-right: 5px;" for="<?php echo esc_attr( $this->get_field_id( 'buyingoptions_' . $value ) ); ?>"><?php echo $desc ?></label>
      <?php endforeach; ?>
      </div>
 		  </p>
  		<p>
  		<label for="<?php echo esc_attr( $this->get_field_id( 'columns' ) ); ?>"><?php esc_attr_e( 'Results Columns / Rows', 'fast-ebay-listings' ); ?></label><br/> 
      <div style="display: flex; flex-direction: row;">
  		<input style="width: 40%; margin-right: 5px;" <?php $this->formIdNameAttrs('columns'); ?> type="text" value="<?php echo esc_attr($columns); ?>" placeholder="<?php echo esc_attr(get_option("fubaby_ebayDefColumns")); ?>">
  		<input style="width: 40%; margin-right: 5px;" <?php $this->formIdNameAttrs('rows'); ?> type="text" value="<?php echo esc_attr($rows); ?>" placeholder="<?php echo esc_attr(get_option("fubaby_ebayDefRows")); ?>">
      </div>
  		</p>
  		<p>  		
  		<label for="<?php echo esc_attr( $this->get_field_id( 'minprice' ) ); ?>"><?php esc_attr_e( 'Min / Max Price', 'fast-ebay-listings' ); ?></label><br/> 
      <div style="display: flex; flex-direction: row;">
  		<input style="width: 40%; margin-right: 5px;" <?php $this->formIdNameAttrs('minprice'); ?> type="text" value="<?php echo esc_attr($minprice); ?>">
  		<input style="width: 40%; margin-right: 5px;" <?php $this->formIdNameAttrs('maxprice'); ?> type="text" value="<?php echo esc_attr($maxprice); ?>">
      </div>
  		</p>
  		<p>
  		<label for="<?php echo esc_attr( $this->get_field_id( 'sort' ) ); ?>"><?php esc_attr_e( 'Sorting', 'fast-ebay-listings' ); ?></label> 
      <select class="widefat" <?php $this->formIdNameAttrs('sort'); ?>>
      <?php foreach ($ebay_sort_order as $value => $desc) printf('<option value="%1$s" %2$s>%3$s</option>', esc_attr($value), $sort == $value ? 'selected' : '', $desc); ?>    
      </select>
  		</p>
  		<p>
  		<label for="<?php echo esc_attr( $this->get_field_id( 'customid' ) ); ?>"><?php esc_attr_e( 'Custom ID', 'fast-ebay-listings' ); ?></label> 
  		<input class="widefat" <?php $this->formIdNameAttrs('customid'); ?> type="text" value="<?php echo esc_attr($customid); ?>" placeholder="<?php echo esc_attr(get_option("fubaby_ebayDefCustomID")); ?>">
  		</p>
  		<p>
  		<label for="<?php echo esc_attr( $this->get_field_id( 'picwidth' ) ); ?>"><?php esc_attr_e( 'Picture Width', 'fast-ebay-listings' ); ?></label> 
  		<input class="widefat" <?php $this->formIdNameAttrs('picwidth'); ?> type="text" value="<?php echo esc_attr($picwidth); ?>" placeholder="<?php echo esc_attr(get_option("fubaby_ebayPicWidthWidget")); ?>">
  		</p>
  		<p>
  		<label for="<?php echo esc_attr( $this->get_field_id( 'slideshow' ) ); ?>"><?php esc_attr_e( 'Slideshow Style / Num Slides', 'fast-ebay-listings' ); ?></label><br/>
      <div style="display: flex; flex-direction: row;">
      <select style="width: 40%; margin-right: 5px;"  <?php $this->formIdNameAttrs('slideshow'); ?> id="<?php echo esc_attr( $this->get_field_id( 'slideshow' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'slideshow' ) ); ?>" >
      <?php foreach ($fu_ebay_slideshow_styles as $value => $desc) printf('<option value="%1$s" %2$s>%3$s</option>', esc_attr($value), $slideshow == $value ? 'selected' : '', $desc); ?>    
      </select>
  		<input style="width: 40%; margin-right: 5px;" <?php $this->formIdNameAttrs('slides'); ?> type="text" value="<?php echo esc_attr($slides); ?>" placeholder="<?php echo esc_attr(get_option("fubaby_ebayDefNumSlides")); ?>">
      </div>
      </p>
      <?php 
	}



	// widget update
	function update($new_instance, $old_instance) 
	{
    global $fu_buying_options;

    $instance = $old_instance;
    // Fields
    $instance['title'] = strip_tags($new_instance['title']);
    $instance['content'] = strip_tags($new_instance['content']);
    $instance['query'] = strip_tags($new_instance['query']);
    $instance['category'] = strip_tags($new_instance['category']);
    $instance['seller'] = strip_tags($new_instance['seller']);
    $instance['sellertype'] = strip_tags($new_instance['sellertype']);
    foreach ($fu_buying_options as $value => $desc)
    {
      $instance['buyingoptions_'.$value] = isset($new_instance['buyingoptions_'.$value]) ? $new_instance['buyingoptions_'.$value] : '';
    }
    $instance['columns'] = intval($new_instance['columns']);
    $instance['rows'] = intval($new_instance['rows']);
    $instance['minprice'] = intval($new_instance['minprice']);
    $instance['maxprice'] = intval($new_instance['maxprice']);
    $instance['sort'] = strip_tags($new_instance['sort']);    
    $instance['customid'] = strip_tags($new_instance['customid']);
    $instance['picwidth'] = strip_tags($new_instance['picwidth']);
    $instance['slideshow'] = strip_tags($new_instance['slideshow']);
    $instance['slides'] = intval($new_instance['slides']);
    return $instance;
	}

	// widget display
	function widget($args, $instance) 
	{    
    global $fu_buying_options;

    extract( $args );
    // these are the widget options
    $title = apply_filters('widget_title', $instance['title']);
    $content = ! empty( $instance['content'] ) ? $instance['content'] : '';
    $query = ! empty( $instance['query'] ) ? $instance['query'] : '';
    $category = ! empty( $instance['category'] ) ? $instance['category'] : '';
    $seller = ! empty( $instance['seller'] ) ? $instance['seller'] : '';
    $sellertype = ! empty( $instance['sellertype'] ) ? $instance['sellertype'] : '';
    $buyingoptionsArr = array();
    foreach ($fu_buying_options as $value => $desc)
    {
      if (isset($instance['buyingoptions_'.$value]) && $instance['buyingoptions_'.$value] == 'on') $buyingoptionsArr[] = $value;
    }
    $buyingoptions = implode("|", $buyingoptionsArr);
    $columns = ! empty( $instance['columns'] ) ? $instance['columns'] : 1;
    $rows = ! empty( $instance['rows'] ) ? $instance['rows'] : 1;
    $minprice = ! empty( $instance['minprice'] ) ? $instance['minprice'] : '';
    $maxprice = ! empty( $instance['maxprice'] ) ? $instance['maxprice'] : '';
    $sort  = ! empty( $instance['sort'] ) ? $instance['sort'] : '';
    $customid = ! empty( $instance['customid'] ) ? $instance['customid'] : '';
    $picwidth = ! empty( $instance['picwidth'] ) ? $instance['picwidth'] : get_option("fubaby_ebayPicWidthWidget");
    $slideshow = ! empty( $instance['slideshow'] ) ? $instance['slideshow'] : 'None';
    $slides = ! empty( $instance['slides'] ) ? $instance['slides'] : 3;
    
    echo $before_widget;
    // Display the widget
    ob_start();    

    // Check if title is set
    if ( $title ) {
      echo $before_title . $title . $after_title;
    }
    
    $apicall = new fuEbayBrowseSearchApiCall($content);
    $apicall->isWidget = true;
    $apicall->picWidth = $picwidth;
    $apicall->setQuery($query);
    $apicall->customId = $customid;
    $apicall->setCategories($category);
    $apicall->setSellers($seller);
    $apicall->setSellerType($sellertype);
    $apicall->setBuyingOptions($buyingoptions);
    $apicall->setTableSize($columns, $rows);
    $apicall->setSlideShow($slideshow, $slides);
    $apicall->minPrice = $minprice;
    $apicall->maxPrice = $maxprice;
    $apicall->setSortOrder($sort);
    $apicall->arrangement = get_option('fubaby_ebayDefArrangementWidget', fuEbayArrangement::TitleBelow);
    $apicall->displayFields = get_option('fubaby_ebayDefDisplayFieldsWidget', fuEbayDisplayFields::ListingDefault);
    
    echo $apicall->call(); 
    echo $after_widget;
    echo ob_get_clean();
	}
}

// register widget
function fuEbayWidgetSearchRegisterFunc() { return register_widget("fuEbayWidgetSearch"); }
add_action('widgets_init', 'fuEbayWidgetSearchRegisterFunc');
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////////
// Dynamic eBay search widget
// Attempts to search eBay for items relating to current wordpress page displayed.
// Will use post title, term title or blog title.
class fuEbayWidgetSearchDynamic extends fuEbayWidgetSearch 
{
	// constructor
	function __construct($name = '') 
	{
    if (empty($name)) $name = __('Fast eBay Dynamic Search', 'fast-ebay-listings');
    parent::__construct($name);
    $this->queryLabel =  __('Default Search Query', 'fast-ebay-listings');
	}
  
	// widget display
	function widget($args, $instance) 
	{
    // Dynamic derive query from current page meta fields, title, term or blog title
    $query = "";
    if (is_singular()) 
    {
      $query = get_post_meta(get_the_ID(), FUBABY_EBAY_META_KEY_PREFIX . "query", true);
      if (empty($query))
        $query = get_the_title();

      $metaValue = get_post_meta(get_the_ID(), FUBABY_EBAY_META_KEY_PREFIX . "category", true);
      if (!empty($metaValue))
        $instance['category'] = $metaValue;
      $metaValue = get_post_meta(get_the_ID(), FUBABY_EBAY_META_KEY_PREFIX . "seller", true);
      if (!empty($metaValue))
        $instance['seller'] = $metaValue;
      $metaValue = get_post_meta(get_the_ID(), FUBABY_EBAY_META_KEY_PREFIX . "minprice", true);
      if (!empty($metaValue))
        $instance['minprice'] = $metaValue;
      $metaValue = get_post_meta(get_the_ID(), FUBABY_EBAY_META_KEY_PREFIX . "maxprice", true);
      if (!empty($metaValue))
        $instance['maxprice'] = $metaValue;
    }
    if (empty($query))
      $query = single_term_title('', false);
    if (empty($query))
      $query = ! empty( $instance['query'] ) ? $instance['query'] : get_bloginfo('name');
     
    extract( $args );
    // these are the widget options
    $title = apply_filters('widget_title', $instance['title']);
    $content = ! empty( $instance['content'] ) ? $instance['content'] : $query;
    $category = ! empty( $instance['category'] ) ? $instance['category'] : '';
    $seller = ! empty( $instance['seller'] ) ? $instance['seller'] : '';
    $sellertype = ! empty( $instance['sellertype'] ) ? $instance['sellertype'] : '';
    $buyingoptions = ! empty( $instance['buyingoptions'] ) ? $instance['buyingoptions'] : '';
    $columns = ! empty( $instance['columns'] ) ? $instance['columns'] : 1;
    $rows = ! empty( $instance['rows'] ) ? $instance['rows'] : 1;
    $minprice = ! empty( $instance['minprice'] ) ? $instance['minprice'] : '';
    $maxprice = ! empty( $instance['maxprice'] ) ? $instance['maxprice'] : '';
    $customid = ! empty( $instance['customid'] ) ? $instance['customid'] : '';
    $picwidth = ! empty( $instance['picwidth'] ) ? $instance['picwidth'] : get_option("fubaby_ebayPicWidthWidget");
    $slideshow = ! empty( $instance['slideshow'] ) ? $instance['slideshow'] : 'None';
    $slides = ! empty( $instance['slides'] ) ? $instance['slides'] : 3;
    
    echo $before_widget;
    // Display the widget
    ob_start();    

    // Check if title is set
    if ( $title )
      echo $before_title . $title . $after_title;
        
    $apicall = new fuEbayBrowseSearchApiCall($content);
    $apicall->isWidget = true;
    $apicall->forceDeferredLoading(); // force deferred loading to help avoid spiders hitting API on every page.
    $apicall->setCachingOptions(FUBABY_EBAY_CALLCACHEEXPIRYDYNSEARCH); // Longer cache expiry to mitigate greater variations. 
    $apicall->picWidth = $picwidth;
    $apicall->setQuery($query);
    $apicall->customId = $customid;
    $apicall->setCategories($category);
    $apicall->setSellers($seller);
    $apicall->setSellerType($sellertype);
    $apicall->setBuyingOptions($buyingoptions);
    $apicall->setTableSize($columns, $rows);
    $apicall->setSlideShow($slideshow, $slides);
    $apicall->minPrice = $minprice;
    $apicall->maxPrice = $maxprice;
    $apicall->arrangement = get_option('fubaby_ebayDefArrangementWidget', fuEbayArrangement::TitleBelow);    
    $apicall->displayFields = get_option('fubaby_ebayDefDisplayFieldsWidget', fuEbayDisplayFields::ListingDefault);

    echo $apicall->call();
    echo $after_widget;
    echo ob_get_clean();
	}
}
 
// register widget
function fuEbayWidgetSearchDynamicRegisterFunc() { return register_widget("fuEbayWidgetSearchDynamic"); }
add_action('widgets_init', 'fuEbayWidgetSearchDynamicRegisterFunc');
 